[Libreoffice-commits] core.git: sw/source
Mike Kaganski (via logerrit)
logerrit at kemper.freedesktop.org
Fri Jul 17 07:12:32 UTC 2020
sw/source/filter/ww8/sprmids.hxx | 685 +++++++++++++++++++-----------------
sw/source/filter/ww8/wrtw8nds.cxx | 24 -
sw/source/filter/ww8/wrtw8num.cxx | 8
sw/source/filter/ww8/wrtw8sty.cxx | 32 -
sw/source/filter/ww8/wrtww8.cxx | 64 +--
sw/source/filter/ww8/wrtww8gr.cxx | 12
sw/source/filter/ww8/ww8atr.cxx | 248 ++++++-------
sw/source/filter/ww8/ww8par.cxx | 4
sw/source/filter/ww8/ww8par2.cxx | 44 +-
sw/source/filter/ww8/ww8par3.cxx | 4
sw/source/filter/ww8/ww8par4.cxx | 2
sw/source/filter/ww8/ww8par6.cxx | 712 +++++++++++++++++++-------------------
sw/source/filter/ww8/ww8scan.cxx | 468 ++++++++++++------------
13 files changed, 1170 insertions(+), 1137 deletions(-)
New commits:
commit 18d9c38932d4c245ad4c8d2eb6bd16b83f770db3
Author: Mike Kaganski <mike.kaganski at collabora.com>
AuthorDate: Fri Jul 17 03:14:28 2020 +0300
Commit: Mike Kaganski <mike.kaganski at collabora.com>
CommitDate: Fri Jul 17 09:11:39 2020 +0200
Use information about sprm structure from [MS-DOC] in GetWW8SprmSearcher
That information is already used in sw/source/filter/ww8/sprmids.hxx.
Just make it available for use by converting the sprms into templated
structs with relevant members.
Inspired by commit 56b04e40ab72b6333ce278ba2980650f5272025f.
This commit changes values for the following sprms:
sprmCPlain (0x2A33): len 0 => len 1
sprmTMerge (0x5624): len variable => len 2
sprmTSplit (0x5625): len variable => len 2
Change-Id: Icd65fc1ef488e7b2db60f13246c76f89176467ac
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/98936
Tested-by: Jenkins
Reviewed-by: Noel Grandin <noel.grandin at collabora.co.uk>
Reviewed-by: Mike Kaganski <mike.kaganski at collabora.com>
diff --git a/sw/source/filter/ww8/sprmids.hxx b/sw/source/filter/ww8/sprmids.hxx
index f06f906fdc49..df17728376bd 100644
--- a/sw/source/filter/ww8/sprmids.hxx
+++ b/sw/source/filter/ww8/sprmids.hxx
@@ -239,7 +239,7 @@ const sal_uInt16 sprmMax = 208;
}
// [MS-DOC] - v20170112 Section 2.2.5.1
-enum class sgc
+enum class SGC
{
paragraph = 1,
character = 2,
@@ -247,7 +247,7 @@ enum class sgc
section = 4,
table = 5
};
-enum class spra
+enum class SPRA
{
operand_toggle_1b_0 = 0,
operand_1b_1 = 1,
@@ -258,347 +258,374 @@ enum class spra
operand_varlen_6 = 6,
operand_3b_7 = 7
};
+
#define SPRM_PART(num, mask, shift) ((static_cast<sal_uInt16>(num) & mask) << shift)
#define SPRM(ispmd, fSpec, sgc, spra) \
SPRM_PART(ispmd, 0x01FF, 0) + SPRM_PART(fSpec, 0x0001, 9) + SPRM_PART(sgc, 0x0007, 10) \
+ SPRM_PART(spra, 0x0007, 13)
-#define SPRM_PAR(ispmd, fSpec, spra) SPRM(ispmd, fSpec, sgc::paragraph, spra)
-#define SPRM_CHR(ispmd, fSpec, spra) SPRM(ispmd, fSpec, sgc::character, spra)
-#define SPRM_PIC(ispmd, fSpec, spra) SPRM(ispmd, fSpec, sgc::picture, spra)
-#define SPRM_SEC(ispmd, fSpec, spra) SPRM(ispmd, fSpec, sgc::section, spra)
-#define SPRM_TBL(ispmd, fSpec, spra) SPRM(ispmd, fSpec, sgc::table, spra)
+
+template <int ispmd, int fSpec, SGC sgc, SPRA spra> struct sprm
+{
+ static constexpr sal_uInt16 val = SPRM(ispmd, fSpec, sgc, spra);
+ static constexpr int len()
+ {
+ switch (spra)
+ {
+ case SPRA::operand_toggle_1b_0:
+ case SPRA::operand_1b_1:
+ return 1;
+ case SPRA::operand_2b_2:
+ case SPRA::operand_2b_4:
+ case SPRA::operand_2b_5:
+ return 2;
+ case SPRA::operand_4b_3:
+ return 4;
+ case SPRA::operand_varlen_6:
+ return 0; // variable
+ case SPRA::operand_3b_7:
+ return 3;
+ }
+ }
+ static constexpr bool varlen() { return (spra == SPRA::operand_varlen_6); }
+};
+
+template <int ispmd, int fSpec, SPRA spra> using sprmPar = sprm<ispmd, fSpec, SGC::paragraph, spra>;
+template <int ispmd, int fSpec, SPRA spra> using sprmChr = sprm<ispmd, fSpec, SGC::character, spra>;
+template <int ispmd, int fSpec, SPRA spra> using sprmPic = sprm<ispmd, fSpec, SGC::picture, spra>;
+template <int ispmd, int fSpec, SPRA spra> using sprmSec = sprm<ispmd, fSpec, SGC::section, spra>;
+template <int ispmd, int fSpec, SPRA spra> using sprmTbl = sprm<ispmd, fSpec, SGC::table, spra>;
// [MS-DOC] - v20170112 Section 2.6.1
-const sal_uInt16 sprmCFRMarkDel = SPRM_CHR(0x00, 0, spra::operand_toggle_1b_0); // 0x0800
-const sal_uInt16 sprmCFRMarkIns = SPRM_CHR(0x01, 0, spra::operand_toggle_1b_0); // 0x0801
-const sal_uInt16 sprmCFFldVanish = SPRM_CHR(0x02, 0, spra::operand_toggle_1b_0); // 0x0802
-const sal_uInt16 sprmCPicLocation = SPRM_CHR(0x03, 1, spra::operand_4b_3); // 0x6A03
-const sal_uInt16 sprmCIbstRMark = SPRM_CHR(0x04, 0, spra::operand_2b_2); // 0x4804
-const sal_uInt16 sprmCDttmRMark = SPRM_CHR(0x05, 0, spra::operand_4b_3); // 0x6805
-const sal_uInt16 sprmCFData = SPRM_CHR(0x06, 0, spra::operand_toggle_1b_0); // 0x0806
-const sal_uInt16 sprmCIdslRMark = SPRM_CHR(0x07, 0, spra::operand_2b_2); // 0x4807
-const sal_uInt16 sprmCSymbol = SPRM_CHR(0x09, 1, spra::operand_4b_3); // 0x6A09
-const sal_uInt16 sprmCFOle2 = SPRM_CHR(0x0A, 0, spra::operand_toggle_1b_0); // 0x080A
-const sal_uInt16 sprmCHighlight = SPRM_CHR(0x0C, 1, spra::operand_1b_1); // 0x2A0C
-const sal_uInt16 sprmCFWebHidden = SPRM_CHR(0x11, 0, spra::operand_toggle_1b_0); // 0x0811
-const sal_uInt16 sprmCRsidProp = SPRM_CHR(0x15, 0, spra::operand_4b_3); // 0x6815
-const sal_uInt16 sprmCRsidText = SPRM_CHR(0x16, 0, spra::operand_4b_3); // 0x6816
-const sal_uInt16 sprmCRsidRMDel = SPRM_CHR(0x17, 0, spra::operand_4b_3); // 0x6817
-const sal_uInt16 sprmCFSpecVanish = SPRM_CHR(0x18, 0, spra::operand_toggle_1b_0); // 0x0818
-const sal_uInt16 sprmCFMathPr = SPRM_CHR(0x1A, 0, spra::operand_varlen_6); // 0xC81A
-const sal_uInt16 sprmCIstd = SPRM_CHR(0x30, 1, spra::operand_2b_2); // 0x4A30
-const sal_uInt16 sprmCIstdPermute = SPRM_CHR(0x31, 1, spra::operand_varlen_6); // 0xCA31
-const sal_uInt16 sprmCPlain = SPRM_CHR(0x33, 1, spra::operand_1b_1); // 0x2A33
-const sal_uInt16 sprmCKcd = SPRM_CHR(0x34, 1, spra::operand_1b_1); // 0x2A34
-const sal_uInt16 sprmCFBold = SPRM_CHR(0x35, 0, spra::operand_toggle_1b_0); // 0x0835
-const sal_uInt16 sprmCFItalic = SPRM_CHR(0x36, 0, spra::operand_toggle_1b_0); // 0x0836
-const sal_uInt16 sprmCFStrike = SPRM_CHR(0x37, 0, spra::operand_toggle_1b_0); // 0x0837
-const sal_uInt16 sprmCFOutline = SPRM_CHR(0x38, 0, spra::operand_toggle_1b_0); // 0x0838
-const sal_uInt16 sprmCFShadow = SPRM_CHR(0x39, 0, spra::operand_toggle_1b_0); // 0x0839
-const sal_uInt16 sprmCFSmallCaps = SPRM_CHR(0x3A, 0, spra::operand_toggle_1b_0); // 0x083A
-const sal_uInt16 sprmCFCaps = SPRM_CHR(0x3B, 0, spra::operand_toggle_1b_0); // 0x083B
-const sal_uInt16 sprmCFVanish = SPRM_CHR(0x3C, 0, spra::operand_toggle_1b_0); // 0x083C
-const sal_uInt16 sprmCKul = SPRM_CHR(0x3E, 1, spra::operand_1b_1); // 0x2A3E
-const sal_uInt16 sprmCDxaSpace = SPRM_CHR(0x40, 0, spra::operand_2b_4); // 0x8840
-const sal_uInt16 sprmCIco = SPRM_CHR(0x42, 1, spra::operand_1b_1); // 0x2A42
-const sal_uInt16 sprmCHps = SPRM_CHR(0x43, 1, spra::operand_2b_2); // 0x4A43
-const sal_uInt16 sprmCHpsPos = SPRM_CHR(0x45, 0, spra::operand_2b_2); // 0x4845
-const sal_uInt16 sprmCMajority = SPRM_CHR(0x47, 1, spra::operand_varlen_6); // 0xCA47
-const sal_uInt16 sprmCIss = SPRM_CHR(0x48, 1, spra::operand_1b_1); // 0x2A48
-const sal_uInt16 sprmCHpsKern = SPRM_CHR(0x4B, 0, spra::operand_2b_2); // 0x484B
-const sal_uInt16 sprmCHresi = SPRM_CHR(0x4E, 0, spra::operand_2b_2); // 0x484E
-const sal_uInt16 sprmCRgFtc0 = SPRM_CHR(0x4F, 1, spra::operand_2b_2); // 0x4A4F
-const sal_uInt16 sprmCRgFtc1 = SPRM_CHR(0x50, 1, spra::operand_2b_2); // 0x4A50
-const sal_uInt16 sprmCRgFtc2 = SPRM_CHR(0x51, 1, spra::operand_2b_2); // 0x4A51
-const sal_uInt16 sprmCCharScale = SPRM_CHR(0x52, 0, spra::operand_2b_2); // 0x4852
-const sal_uInt16 sprmCFDStrike = SPRM_CHR(0x53, 1, spra::operand_1b_1); // 0x2A53
-const sal_uInt16 sprmCFImprint = SPRM_CHR(0x54, 0, spra::operand_toggle_1b_0); // 0x0854
-const sal_uInt16 sprmCFSpec = SPRM_CHR(0x55, 0, spra::operand_toggle_1b_0); // 0x0855
-const sal_uInt16 sprmCFObj = SPRM_CHR(0x56, 0, spra::operand_toggle_1b_0); // 0x0856
-const sal_uInt16 sprmCPropRMark90 = SPRM_CHR(0x57, 1, spra::operand_varlen_6); // 0xCA57
-const sal_uInt16 sprmCFEmboss = SPRM_CHR(0x58, 0, spra::operand_toggle_1b_0); // 0x0858
-const sal_uInt16 sprmCSfxText = SPRM_CHR(0x59, 0, spra::operand_1b_1); // 0x2859
-const sal_uInt16 sprmCFBiDi = SPRM_CHR(0x5A, 0, spra::operand_toggle_1b_0); // 0x085A
-const sal_uInt16 sprmCFBoldBi = SPRM_CHR(0x5C, 0, spra::operand_toggle_1b_0); // 0x085C
-const sal_uInt16 sprmCFItalicBi = SPRM_CHR(0x5D, 0, spra::operand_toggle_1b_0); // 0x085D
-const sal_uInt16 sprmCFtcBi = SPRM_CHR(0x5E, 1, spra::operand_2b_2); // 0x4A5E
-const sal_uInt16 sprmCLidBi = SPRM_CHR(0x5F, 0, spra::operand_2b_2); // 0x485F
-const sal_uInt16 sprmCIcoBi = SPRM_CHR(0x60, 1, spra::operand_2b_2); // 0x4A60
-const sal_uInt16 sprmCHpsBi = SPRM_CHR(0x61, 1, spra::operand_2b_2); // 0x4A61
-const sal_uInt16 sprmCDispFldRMark = SPRM_CHR(0x62, 1, spra::operand_varlen_6); // 0xCA62
-const sal_uInt16 sprmCIbstRMarkDel = SPRM_CHR(0x63, 0, spra::operand_2b_2); // 0x4863
-const sal_uInt16 sprmCDttmRMarkDel = SPRM_CHR(0x64, 0, spra::operand_4b_3); // 0x6864
-const sal_uInt16 sprmCBrc80 = SPRM_CHR(0x65, 0, spra::operand_4b_3); // 0x6865
-const sal_uInt16 sprmCShd80 = SPRM_CHR(0x66, 0, spra::operand_2b_2); // 0x4866
-const sal_uInt16 sprmCIdslRMarkDel = SPRM_CHR(0x67, 0, spra::operand_2b_2); // 0x4867
-const sal_uInt16 sprmCFUsePgsuSettings = SPRM_CHR(0x68, 0, spra::operand_toggle_1b_0); // 0x0868
-const sal_uInt16 sprmCRgLid0_80 = SPRM_CHR(0x6D, 0, spra::operand_2b_2); // 0x486D
-const sal_uInt16 sprmCRgLid1_80 = SPRM_CHR(0x6E, 0, spra::operand_2b_2); // 0x486E
-const sal_uInt16 sprmCIdctHint = SPRM_CHR(0x6F, 0, spra::operand_1b_1); // 0x286F
-const sal_uInt16 sprmCCv = SPRM_CHR(0x70, 0, spra::operand_4b_3); // 0x6870
-const sal_uInt16 sprmCShd = SPRM_CHR(0x71, 1, spra::operand_varlen_6); // 0xCA71
-const sal_uInt16 sprmCBrc = SPRM_CHR(0x72, 1, spra::operand_varlen_6); // 0xCA72
-const sal_uInt16 sprmCRgLid0 = SPRM_CHR(0x73, 0, spra::operand_2b_2); // 0x4873
-const sal_uInt16 sprmCRgLid1 = SPRM_CHR(0x74, 0, spra::operand_2b_2); // 0x4874
-const sal_uInt16 sprmCFNoProof = SPRM_CHR(0x75, 0, spra::operand_toggle_1b_0); // 0x0875
-const sal_uInt16 sprmCFitText = SPRM_CHR(0x76, 1, spra::operand_varlen_6); // 0xCA76
-const sal_uInt16 sprmCCvUl = SPRM_CHR(0x77, 0, spra::operand_4b_3); // 0x6877
-const sal_uInt16 sprmCFELayout = SPRM_CHR(0x78, 1, spra::operand_varlen_6); // 0xCA78
-const sal_uInt16 sprmCLbcCRJ = SPRM_CHR(0x79, 0, spra::operand_1b_1); // 0x2879
-const sal_uInt16 sprmCFComplexScripts = SPRM_CHR(0x82, 0, spra::operand_toggle_1b_0); // 0x0882
-const sal_uInt16 sprmCWall = SPRM_CHR(0x83, 1, spra::operand_1b_1); // 0x2A83
-const sal_uInt16 sprmCCnf = SPRM_CHR(0x85, 1, spra::operand_varlen_6); // 0xCA85
-const sal_uInt16 sprmCNeedFontFixup = SPRM_CHR(0x86, 1, spra::operand_1b_1); // 0x2A86
-const sal_uInt16 sprmCPbiIBullet = SPRM_CHR(0x87, 0, spra::operand_4b_3); // 0x6887
-const sal_uInt16 sprmCPbiGrf = SPRM_CHR(0x88, 0, spra::operand_2b_2); // 0x4888
-const sal_uInt16 sprmCPropRMark = SPRM_CHR(0x89, 1, spra::operand_varlen_6); // 0xCA89
-const sal_uInt16 sprmCFSdtVanish = SPRM_CHR(0x90, 1, spra::operand_1b_1); // 0x2A90
+using CFRMarkDel = sprmChr<0x00, 0, SPRA::operand_toggle_1b_0>; // 0x0800
+using CFRMarkIns = sprmChr<0x01, 0, SPRA::operand_toggle_1b_0>; // 0x0801
+using CFFldVanish = sprmChr<0x02, 0, SPRA::operand_toggle_1b_0>; // 0x0802
+using CPicLocation = sprmChr<0x03, 1, SPRA::operand_4b_3>; // 0x6A03
+using CIbstRMark = sprmChr<0x04, 0, SPRA::operand_2b_2>; // 0x4804
+using CDttmRMark = sprmChr<0x05, 0, SPRA::operand_4b_3>; // 0x6805
+using CFData = sprmChr<0x06, 0, SPRA::operand_toggle_1b_0>; // 0x0806
+using CIdslRMark = sprmChr<0x07, 0, SPRA::operand_2b_2>; // 0x4807
+using CSymbol = sprmChr<0x09, 1, SPRA::operand_4b_3>; // 0x6A09
+using CFOle2 = sprmChr<0x0A, 0, SPRA::operand_toggle_1b_0>; // 0x080A
+using CHighlight = sprmChr<0x0C, 1, SPRA::operand_1b_1>; // 0x2A0C
+using CFWebHidden = sprmChr<0x11, 0, SPRA::operand_toggle_1b_0>; // 0x0811
+using CRsidProp = sprmChr<0x15, 0, SPRA::operand_4b_3>; // 0x6815
+using CRsidText = sprmChr<0x16, 0, SPRA::operand_4b_3>; // 0x6816
+using CRsidRMDel = sprmChr<0x17, 0, SPRA::operand_4b_3>; // 0x6817
+using CFSpecVanish = sprmChr<0x18, 0, SPRA::operand_toggle_1b_0>; // 0x0818
+using CFMathPr = sprmChr<0x1A, 0, SPRA::operand_varlen_6>; // 0xC81A
+using CIstd = sprmChr<0x30, 1, SPRA::operand_2b_2>; // 0x4A30
+using CIstdPermute = sprmChr<0x31, 1, SPRA::operand_varlen_6>; // 0xCA31
+using CPlain = sprmChr<0x33, 1, SPRA::operand_1b_1>; // 0x2A33
+using CKcd = sprmChr<0x34, 1, SPRA::operand_1b_1>; // 0x2A34
+using CFBold = sprmChr<0x35, 0, SPRA::operand_toggle_1b_0>; // 0x0835
+using CFItalic = sprmChr<0x36, 0, SPRA::operand_toggle_1b_0>; // 0x0836
+using CFStrike = sprmChr<0x37, 0, SPRA::operand_toggle_1b_0>; // 0x0837
+using CFOutline = sprmChr<0x38, 0, SPRA::operand_toggle_1b_0>; // 0x0838
+using CFShadow = sprmChr<0x39, 0, SPRA::operand_toggle_1b_0>; // 0x0839
+using CFSmallCaps = sprmChr<0x3A, 0, SPRA::operand_toggle_1b_0>; // 0x083A
+using CFCaps = sprmChr<0x3B, 0, SPRA::operand_toggle_1b_0>; // 0x083B
+using CFVanish = sprmChr<0x3C, 0, SPRA::operand_toggle_1b_0>; // 0x083C
+using CKul = sprmChr<0x3E, 1, SPRA::operand_1b_1>; // 0x2A3E
+using CDxaSpace = sprmChr<0x40, 0, SPRA::operand_2b_4>; // 0x8840
+using CIco = sprmChr<0x42, 1, SPRA::operand_1b_1>; // 0x2A42
+using CHps = sprmChr<0x43, 1, SPRA::operand_2b_2>; // 0x4A43
+using CHpsPos = sprmChr<0x45, 0, SPRA::operand_2b_2>; // 0x4845
+using CMajority = sprmChr<0x47, 1, SPRA::operand_varlen_6>; // 0xCA47
+using CIss = sprmChr<0x48, 1, SPRA::operand_1b_1>; // 0x2A48
+using CHpsKern = sprmChr<0x4B, 0, SPRA::operand_2b_2>; // 0x484B
+using CHresi = sprmChr<0x4E, 0, SPRA::operand_2b_2>; // 0x484E
+using CRgFtc0 = sprmChr<0x4F, 1, SPRA::operand_2b_2>; // 0x4A4F
+using CRgFtc1 = sprmChr<0x50, 1, SPRA::operand_2b_2>; // 0x4A50
+using CRgFtc2 = sprmChr<0x51, 1, SPRA::operand_2b_2>; // 0x4A51
+using CCharScale = sprmChr<0x52, 0, SPRA::operand_2b_2>; // 0x4852
+using CFDStrike = sprmChr<0x53, 1, SPRA::operand_1b_1>; // 0x2A53
+using CFImprint = sprmChr<0x54, 0, SPRA::operand_toggle_1b_0>; // 0x0854
+using CFSpec = sprmChr<0x55, 0, SPRA::operand_toggle_1b_0>; // 0x0855
+using CFObj = sprmChr<0x56, 0, SPRA::operand_toggle_1b_0>; // 0x0856
+using CPropRMark90 = sprmChr<0x57, 1, SPRA::operand_varlen_6>; // 0xCA57
+using CFEmboss = sprmChr<0x58, 0, SPRA::operand_toggle_1b_0>; // 0x0858
+using CSfxText = sprmChr<0x59, 0, SPRA::operand_1b_1>; // 0x2859
+using CFBiDi = sprmChr<0x5A, 0, SPRA::operand_toggle_1b_0>; // 0x085A
+using CFBoldBi = sprmChr<0x5C, 0, SPRA::operand_toggle_1b_0>; // 0x085C
+using CFItalicBi = sprmChr<0x5D, 0, SPRA::operand_toggle_1b_0>; // 0x085D
+using CFtcBi = sprmChr<0x5E, 1, SPRA::operand_2b_2>; // 0x4A5E
+using CLidBi = sprmChr<0x5F, 0, SPRA::operand_2b_2>; // 0x485F
+using CIcoBi = sprmChr<0x60, 1, SPRA::operand_2b_2>; // 0x4A60
+using CHpsBi = sprmChr<0x61, 1, SPRA::operand_2b_2>; // 0x4A61
+using CDispFldRMark = sprmChr<0x62, 1, SPRA::operand_varlen_6>; // 0xCA62
+using CIbstRMarkDel = sprmChr<0x63, 0, SPRA::operand_2b_2>; // 0x4863
+using CDttmRMarkDel = sprmChr<0x64, 0, SPRA::operand_4b_3>; // 0x6864
+using CBrc80 = sprmChr<0x65, 0, SPRA::operand_4b_3>; // 0x6865
+using CShd80 = sprmChr<0x66, 0, SPRA::operand_2b_2>; // 0x4866
+using CIdslRMarkDel = sprmChr<0x67, 0, SPRA::operand_2b_2>; // 0x4867
+using CFUsePgsuSettings = sprmChr<0x68, 0, SPRA::operand_toggle_1b_0>; // 0x0868
+using CRgLid0_80 = sprmChr<0x6D, 0, SPRA::operand_2b_2>; // 0x486D
+using CRgLid1_80 = sprmChr<0x6E, 0, SPRA::operand_2b_2>; // 0x486E
+using CIdctHint = sprmChr<0x6F, 0, SPRA::operand_1b_1>; // 0x286F
+using CCv = sprmChr<0x70, 0, SPRA::operand_4b_3>; // 0x6870
+using CShd = sprmChr<0x71, 1, SPRA::operand_varlen_6>; // 0xCA71
+using CBrc = sprmChr<0x72, 1, SPRA::operand_varlen_6>; // 0xCA72
+using CRgLid0 = sprmChr<0x73, 0, SPRA::operand_2b_2>; // 0x4873
+using CRgLid1 = sprmChr<0x74, 0, SPRA::operand_2b_2>; // 0x4874
+using CFNoProof = sprmChr<0x75, 0, SPRA::operand_toggle_1b_0>; // 0x0875
+using CFitText = sprmChr<0x76, 1, SPRA::operand_varlen_6>; // 0xCA76
+using CCvUl = sprmChr<0x77, 0, SPRA::operand_4b_3>; // 0x6877
+using CFELayout = sprmChr<0x78, 1, SPRA::operand_varlen_6>; // 0xCA78
+using CLbcCRJ = sprmChr<0x79, 0, SPRA::operand_1b_1>; // 0x2879
+using CFComplexScripts = sprmChr<0x82, 0, SPRA::operand_toggle_1b_0>; // 0x0882
+using CWall = sprmChr<0x83, 1, SPRA::operand_1b_1>; // 0x2A83
+using CCnf = sprmChr<0x85, 1, SPRA::operand_varlen_6>; // 0xCA85
+using CNeedFontFixup = sprmChr<0x86, 1, SPRA::operand_1b_1>; // 0x2A86
+using CPbiIBullet = sprmChr<0x87, 0, SPRA::operand_4b_3>; // 0x6887
+using CPbiGrf = sprmChr<0x88, 0, SPRA::operand_2b_2>; // 0x4888
+using CPropRMark = sprmChr<0x89, 1, SPRA::operand_varlen_6>; // 0xCA89
+using CFSdtVanish = sprmChr<0x90, 1, SPRA::operand_1b_1>; // 0x2A90
// [MS-DOC] - v20170112 Section 2.6.2
-const sal_uInt16 sprmPIstd = SPRM_PAR(0x00, 1, spra::operand_2b_2); // 0x4600
-const sal_uInt16 sprmPIstdPermute = SPRM_PAR(0x01, 1, spra::operand_varlen_6); // 0xC601
-const sal_uInt16 sprmPIncLvl = SPRM_PAR(0x02, 1, spra::operand_1b_1); // 0x2602
-const sal_uInt16 sprmPJc80 = SPRM_PAR(0x03, 0, spra::operand_1b_1); // 0x2403
-const sal_uInt16 sprmPFKeep = SPRM_PAR(0x05, 0, spra::operand_1b_1); // 0x2405
-const sal_uInt16 sprmPFKeepFollow = SPRM_PAR(0x06, 0, spra::operand_1b_1); // 0x2406
-const sal_uInt16 sprmPFPageBreakBefore = SPRM_PAR(0x07, 0, spra::operand_1b_1); // 0x2407
-const sal_uInt16 sprmPIlvl = SPRM_PAR(0x0A, 1, spra::operand_1b_1); // 0x260A
-const sal_uInt16 sprmPIlfo = SPRM_PAR(0x0B, 1, spra::operand_2b_2); // 0x460B
-const sal_uInt16 sprmPFNoLineNumb = SPRM_PAR(0x0C, 0, spra::operand_1b_1); // 0x240C
-const sal_uInt16 sprmPChgTabsPapx = SPRM_PAR(0x0D, 1, spra::operand_varlen_6); // 0xC60D
-const sal_uInt16 sprmPDxaRight80 = SPRM_PAR(0x0E, 0, spra::operand_2b_4); // 0x840E
-const sal_uInt16 sprmPDxaLeft80 = SPRM_PAR(0x0F, 0, spra::operand_2b_4); // 0x840F
-const sal_uInt16 sprmPNest80 = SPRM_PAR(0x10, 1, spra::operand_2b_2); // 0x4610
-const sal_uInt16 sprmPDxaLeft180 = SPRM_PAR(0x11, 0, spra::operand_2b_4); // 0x8411
-const sal_uInt16 sprmPDyaLine = SPRM_PAR(0x12, 0, spra::operand_4b_3); // 0x6412
-const sal_uInt16 sprmPDyaBefore = SPRM_PAR(0x13, 0, spra::operand_2b_5); // 0xA413
-const sal_uInt16 sprmPDyaAfter = SPRM_PAR(0x14, 0, spra::operand_2b_5); // 0xA414
-const sal_uInt16 sprmPChgTabs = SPRM_PAR(0x15, 1, spra::operand_varlen_6); // 0xC615
-const sal_uInt16 sprmPFInTable = SPRM_PAR(0x16, 0, spra::operand_1b_1); // 0x2416
-const sal_uInt16 sprmPFTtp = SPRM_PAR(0x17, 0, spra::operand_1b_1); // 0x2417
-const sal_uInt16 sprmPDxaAbs = SPRM_PAR(0x18, 0, spra::operand_2b_4); // 0x8418
-const sal_uInt16 sprmPDyaAbs = SPRM_PAR(0x19, 0, spra::operand_2b_4); // 0x8419
-const sal_uInt16 sprmPDxaWidth = SPRM_PAR(0x1A, 0, spra::operand_2b_4); // 0x841A
-const sal_uInt16 sprmPPc = SPRM_PAR(0x1B, 1, spra::operand_1b_1); // 0x261B
-const sal_uInt16 sprmPWr = SPRM_PAR(0x23, 0, spra::operand_1b_1); // 0x2423
-const sal_uInt16 sprmPBrcTop80 = SPRM_PAR(0x24, 0, spra::operand_4b_3); // 0x6424
-const sal_uInt16 sprmPBrcLeft80 = SPRM_PAR(0x25, 0, spra::operand_4b_3); // 0x6425
-const sal_uInt16 sprmPBrcBottom80 = SPRM_PAR(0x26, 0, spra::operand_4b_3); // 0x6426
-const sal_uInt16 sprmPBrcRight80 = SPRM_PAR(0x27, 0, spra::operand_4b_3); // 0x6427
-const sal_uInt16 sprmPBrcBetween80 = SPRM_PAR(0x28, 0, spra::operand_4b_3); // 0x6428
-const sal_uInt16 sprmPBrcBar80 = SPRM_PAR(0x29, 1, spra::operand_4b_3); // 0x6629
-const sal_uInt16 sprmPFNoAutoHyph = SPRM_PAR(0x2A, 0, spra::operand_1b_1); // 0x242A
-const sal_uInt16 sprmPWHeightAbs = SPRM_PAR(0x2B, 0, spra::operand_2b_2); // 0x442B
-const sal_uInt16 sprmPDcs = SPRM_PAR(0x2C, 0, spra::operand_2b_2); // 0x442C
-const sal_uInt16 sprmPShd80 = SPRM_PAR(0x2D, 0, spra::operand_2b_2); // 0x442D
-const sal_uInt16 sprmPDyaFromText = SPRM_PAR(0x2E, 0, spra::operand_2b_4); // 0x842E
-const sal_uInt16 sprmPDxaFromText = SPRM_PAR(0x2F, 0, spra::operand_2b_4); // 0x842F
-const sal_uInt16 sprmPFLocked = SPRM_PAR(0x30, 0, spra::operand_1b_1); // 0x2430
-const sal_uInt16 sprmPFWidowControl = SPRM_PAR(0x31, 0, spra::operand_1b_1); // 0x2431
-const sal_uInt16 sprmPFKinsoku = SPRM_PAR(0x33, 0, spra::operand_1b_1); // 0x2433
-const sal_uInt16 sprmPFWordWrap = SPRM_PAR(0x34, 0, spra::operand_1b_1); // 0x2434
-const sal_uInt16 sprmPFOverflowPunct = SPRM_PAR(0x35, 0, spra::operand_1b_1); // 0x2435
-const sal_uInt16 sprmPFTopLinePunct = SPRM_PAR(0x36, 0, spra::operand_1b_1); // 0x2436
-const sal_uInt16 sprmPFAutoSpaceDE = SPRM_PAR(0x37, 0, spra::operand_1b_1); // 0x2437
-const sal_uInt16 sprmPFAutoSpaceDN = SPRM_PAR(0x38, 0, spra::operand_1b_1); // 0x2438
-const sal_uInt16 sprmPWAlignFont = SPRM_PAR(0x39, 0, spra::operand_2b_2); // 0x4439
-const sal_uInt16 sprmPFrameTextFlow = SPRM_PAR(0x3A, 0, spra::operand_2b_2); // 0x443A
-const sal_uInt16 sprmPOutLvl = SPRM_PAR(0x40, 1, spra::operand_1b_1); // 0x2640
-const sal_uInt16 sprmPFBiDi = SPRM_PAR(0x41, 0, spra::operand_1b_1); // 0x2441
-const sal_uInt16 sprmPFNumRMIns = SPRM_PAR(0x43, 0, spra::operand_1b_1); // 0x2443
-const sal_uInt16 sprmPNumRM = SPRM_PAR(0x45, 1, spra::operand_varlen_6); // 0xC645
-const sal_uInt16 sprmPHugePapx = SPRM_PAR(0x46, 1, spra::operand_4b_3); // 0x6646
-const sal_uInt16 sprmPFUsePgsuSettings = SPRM_PAR(0x47, 0, spra::operand_1b_1); // 0x2447
-const sal_uInt16 sprmPFAdjustRight = SPRM_PAR(0x48, 0, spra::operand_1b_1); // 0x2448
-const sal_uInt16 sprmPItap = SPRM_PAR(0x49, 1, spra::operand_4b_3); // 0x6649
-const sal_uInt16 sprmPDtap = SPRM_PAR(0x4A, 1, spra::operand_4b_3); // 0x664A
-const sal_uInt16 sprmPFInnerTableCell = SPRM_PAR(0x4B, 0, spra::operand_1b_1); // 0x244B
-const sal_uInt16 sprmPFInnerTtp = SPRM_PAR(0x4C, 0, spra::operand_1b_1); // 0x244C
-const sal_uInt16 sprmPShd = SPRM_PAR(0x4D, 1, spra::operand_varlen_6); // 0xC64D
-const sal_uInt16 sprmPBrcTop = SPRM_PAR(0x4E, 1, spra::operand_varlen_6); // 0xC64E
-const sal_uInt16 sprmPBrcLeft = SPRM_PAR(0x4F, 1, spra::operand_varlen_6); // 0xC64F
-const sal_uInt16 sprmPBrcBottom = SPRM_PAR(0x50, 1, spra::operand_varlen_6); // 0xC650
-const sal_uInt16 sprmPBrcRight = SPRM_PAR(0x51, 1, spra::operand_varlen_6); // 0xC651
-const sal_uInt16 sprmPBrcBetween = SPRM_PAR(0x52, 1, spra::operand_varlen_6); // 0xC652
-const sal_uInt16 sprmPBrcBar = SPRM_PAR(0x53, 1, spra::operand_varlen_6); // 0xC653
-const sal_uInt16 sprmPDxcRight = SPRM_PAR(0x55, 0, spra::operand_2b_2); // 0x4455
-const sal_uInt16 sprmPDxcLeft = SPRM_PAR(0x56, 0, spra::operand_2b_2); // 0x4456
-const sal_uInt16 sprmPDxcLeft1 = SPRM_PAR(0x57, 0, spra::operand_2b_2); // 0x4457
-const sal_uInt16 sprmPDylBefore = SPRM_PAR(0x58, 0, spra::operand_2b_2); // 0x4458
-const sal_uInt16 sprmPDylAfter = SPRM_PAR(0x59, 0, spra::operand_2b_2); // 0x4459
-const sal_uInt16 sprmPFOpenTch = SPRM_PAR(0x5A, 0, spra::operand_1b_1); // 0x245A
-const sal_uInt16 sprmPFDyaBeforeAuto = SPRM_PAR(0x5B, 0, spra::operand_1b_1); // 0x245B
-const sal_uInt16 sprmPFDyaAfterAuto = SPRM_PAR(0x5C, 0, spra::operand_1b_1); // 0x245C
-const sal_uInt16 sprmPDxaRight = SPRM_PAR(0x5D, 0, spra::operand_2b_4); // 0x845D
-const sal_uInt16 sprmPDxaLeft = SPRM_PAR(0x5E, 0, spra::operand_2b_4); // 0x845E
-const sal_uInt16 sprmPNest = SPRM_PAR(0x5F, 1, spra::operand_2b_2); // 0x465F
-const sal_uInt16 sprmPDxaLeft1 = SPRM_PAR(0x60, 0, spra::operand_2b_4); // 0x8460
-const sal_uInt16 sprmPJc = SPRM_PAR(0x61, 0, spra::operand_1b_1); // 0x2461
-const sal_uInt16 sprmPFNoAllowOverlap = SPRM_PAR(0x62, 0, spra::operand_1b_1); // 0x2462
-const sal_uInt16 sprmPWall = SPRM_PAR(0x64, 1, spra::operand_1b_1); // 0x2664
-const sal_uInt16 sprmPIpgp = SPRM_PAR(0x65, 0, spra::operand_4b_3); // 0x6465
-const sal_uInt16 sprmPCnf = SPRM_PAR(0x66, 1, spra::operand_varlen_6); // 0xC666
-const sal_uInt16 sprmPRsid = SPRM_PAR(0x67, 0, spra::operand_4b_3); // 0x6467
-const sal_uInt16 sprmPIstdListPermute = SPRM_PAR(0x69, 1, spra::operand_varlen_6); // 0xC669
-const sal_uInt16 sprmPTableProps = SPRM_PAR(0x6B, 0, spra::operand_4b_3); // 0x646B
-const sal_uInt16 sprmPTIstdInfo = SPRM_PAR(0x6C, 1, spra::operand_varlen_6); // 0xC66C
-const sal_uInt16 sprmPFContextualSpacing = SPRM_PAR(0x6D, 0, spra::operand_1b_1); // 0x246D
-const sal_uInt16 sprmPPropRMark = SPRM_PAR(0x6F, 1, spra::operand_varlen_6); // 0xC66F
-const sal_uInt16 sprmPFMirrorIndents = SPRM_PAR(0x70, 0, spra::operand_1b_1); // 0x2470
-const sal_uInt16 sprmPTtwo = SPRM_PAR(0x71, 0, spra::operand_1b_1); // 0x2471
+using PIstd = sprmPar<0x00, 1, SPRA::operand_2b_2>; // 0x4600
+using PIstdPermute = sprmPar<0x01, 1, SPRA::operand_varlen_6>; // 0xC601
+using PIncLvl = sprmPar<0x02, 1, SPRA::operand_1b_1>; // 0x2602
+using PJc80 = sprmPar<0x03, 0, SPRA::operand_1b_1>; // 0x2403
+using PFKeep = sprmPar<0x05, 0, SPRA::operand_1b_1>; // 0x2405
+using PFKeepFollow = sprmPar<0x06, 0, SPRA::operand_1b_1>; // 0x2406
+using PFPageBreakBefore = sprmPar<0x07, 0, SPRA::operand_1b_1>; // 0x2407
+using PIlvl = sprmPar<0x0A, 1, SPRA::operand_1b_1>; // 0x260A
+using PIlfo = sprmPar<0x0B, 1, SPRA::operand_2b_2>; // 0x460B
+using PFNoLineNumb = sprmPar<0x0C, 0, SPRA::operand_1b_1>; // 0x240C
+using PChgTabsPapx = sprmPar<0x0D, 1, SPRA::operand_varlen_6>; // 0xC60D
+using PDxaRight80 = sprmPar<0x0E, 0, SPRA::operand_2b_4>; // 0x840E
+using PDxaLeft80 = sprmPar<0x0F, 0, SPRA::operand_2b_4>; // 0x840F
+using PNest80 = sprmPar<0x10, 1, SPRA::operand_2b_2>; // 0x4610
+using PDxaLeft180 = sprmPar<0x11, 0, SPRA::operand_2b_4>; // 0x8411
+using PDyaLine = sprmPar<0x12, 0, SPRA::operand_4b_3>; // 0x6412
+using PDyaBefore = sprmPar<0x13, 0, SPRA::operand_2b_5>; // 0xA413
+using PDyaAfter = sprmPar<0x14, 0, SPRA::operand_2b_5>; // 0xA414
+using PChgTabs = sprmPar<0x15, 1, SPRA::operand_varlen_6>; // 0xC615
+using PFInTable = sprmPar<0x16, 0, SPRA::operand_1b_1>; // 0x2416
+using PFTtp = sprmPar<0x17, 0, SPRA::operand_1b_1>; // 0x2417
+using PDxaAbs = sprmPar<0x18, 0, SPRA::operand_2b_4>; // 0x8418
+using PDyaAbs = sprmPar<0x19, 0, SPRA::operand_2b_4>; // 0x8419
+using PDxaWidth = sprmPar<0x1A, 0, SPRA::operand_2b_4>; // 0x841A
+using PPc = sprmPar<0x1B, 1, SPRA::operand_1b_1>; // 0x261B
+using PWr = sprmPar<0x23, 0, SPRA::operand_1b_1>; // 0x2423
+using PBrcTop80 = sprmPar<0x24, 0, SPRA::operand_4b_3>; // 0x6424
+using PBrcLeft80 = sprmPar<0x25, 0, SPRA::operand_4b_3>; // 0x6425
+using PBrcBottom80 = sprmPar<0x26, 0, SPRA::operand_4b_3>; // 0x6426
+using PBrcRight80 = sprmPar<0x27, 0, SPRA::operand_4b_3>; // 0x6427
+using PBrcBetween80 = sprmPar<0x28, 0, SPRA::operand_4b_3>; // 0x6428
+using PBrcBar80 = sprmPar<0x29, 1, SPRA::operand_4b_3>; // 0x6629
+using PFNoAutoHyph = sprmPar<0x2A, 0, SPRA::operand_1b_1>; // 0x242A
+using PWHeightAbs = sprmPar<0x2B, 0, SPRA::operand_2b_2>; // 0x442B
+using PDcs = sprmPar<0x2C, 0, SPRA::operand_2b_2>; // 0x442C
+using PShd80 = sprmPar<0x2D, 0, SPRA::operand_2b_2>; // 0x442D
+using PDyaFromText = sprmPar<0x2E, 0, SPRA::operand_2b_4>; // 0x842E
+using PDxaFromText = sprmPar<0x2F, 0, SPRA::operand_2b_4>; // 0x842F
+using PFLocked = sprmPar<0x30, 0, SPRA::operand_1b_1>; // 0x2430
+using PFWidowControl = sprmPar<0x31, 0, SPRA::operand_1b_1>; // 0x2431
+using PFKinsoku = sprmPar<0x33, 0, SPRA::operand_1b_1>; // 0x2433
+using PFWordWrap = sprmPar<0x34, 0, SPRA::operand_1b_1>; // 0x2434
+using PFOverflowPunct = sprmPar<0x35, 0, SPRA::operand_1b_1>; // 0x2435
+using PFTopLinePunct = sprmPar<0x36, 0, SPRA::operand_1b_1>; // 0x2436
+using PFAutoSpaceDE = sprmPar<0x37, 0, SPRA::operand_1b_1>; // 0x2437
+using PFAutoSpaceDN = sprmPar<0x38, 0, SPRA::operand_1b_1>; // 0x2438
+using PWAlignFont = sprmPar<0x39, 0, SPRA::operand_2b_2>; // 0x4439
+using PFrameTextFlow = sprmPar<0x3A, 0, SPRA::operand_2b_2>; // 0x443A
+using POutLvl = sprmPar<0x40, 1, SPRA::operand_1b_1>; // 0x2640
+using PFBiDi = sprmPar<0x41, 0, SPRA::operand_1b_1>; // 0x2441
+using PFNumRMIns = sprmPar<0x43, 0, SPRA::operand_1b_1>; // 0x2443
+using PNumRM = sprmPar<0x45, 1, SPRA::operand_varlen_6>; // 0xC645
+using PHugePapx = sprmPar<0x46, 1, SPRA::operand_4b_3>; // 0x6646
+using PFUsePgsuSettings = sprmPar<0x47, 0, SPRA::operand_1b_1>; // 0x2447
+using PFAdjustRight = sprmPar<0x48, 0, SPRA::operand_1b_1>; // 0x2448
+using PItap = sprmPar<0x49, 1, SPRA::operand_4b_3>; // 0x6649
+using PDtap = sprmPar<0x4A, 1, SPRA::operand_4b_3>; // 0x664A
+using PFInnerTableCell = sprmPar<0x4B, 0, SPRA::operand_1b_1>; // 0x244B
+using PFInnerTtp = sprmPar<0x4C, 0, SPRA::operand_1b_1>; // 0x244C
+using PShd = sprmPar<0x4D, 1, SPRA::operand_varlen_6>; // 0xC64D
+using PBrcTop = sprmPar<0x4E, 1, SPRA::operand_varlen_6>; // 0xC64E
+using PBrcLeft = sprmPar<0x4F, 1, SPRA::operand_varlen_6>; // 0xC64F
+using PBrcBottom = sprmPar<0x50, 1, SPRA::operand_varlen_6>; // 0xC650
+using PBrcRight = sprmPar<0x51, 1, SPRA::operand_varlen_6>; // 0xC651
+using PBrcBetween = sprmPar<0x52, 1, SPRA::operand_varlen_6>; // 0xC652
+using PBrcBar = sprmPar<0x53, 1, SPRA::operand_varlen_6>; // 0xC653
+using PDxcRight = sprmPar<0x55, 0, SPRA::operand_2b_2>; // 0x4455
+using PDxcLeft = sprmPar<0x56, 0, SPRA::operand_2b_2>; // 0x4456
+using PDxcLeft1 = sprmPar<0x57, 0, SPRA::operand_2b_2>; // 0x4457
+using PDylBefore = sprmPar<0x58, 0, SPRA::operand_2b_2>; // 0x4458
+using PDylAfter = sprmPar<0x59, 0, SPRA::operand_2b_2>; // 0x4459
+using PFOpenTch = sprmPar<0x5A, 0, SPRA::operand_1b_1>; // 0x245A
+using PFDyaBeforeAuto = sprmPar<0x5B, 0, SPRA::operand_1b_1>; // 0x245B
+using PFDyaAfterAuto = sprmPar<0x5C, 0, SPRA::operand_1b_1>; // 0x245C
+using PDxaRight = sprmPar<0x5D, 0, SPRA::operand_2b_4>; // 0x845D
+using PDxaLeft = sprmPar<0x5E, 0, SPRA::operand_2b_4>; // 0x845E
+using PNest = sprmPar<0x5F, 1, SPRA::operand_2b_2>; // 0x465F
+using PDxaLeft1 = sprmPar<0x60, 0, SPRA::operand_2b_4>; // 0x8460
+using PJc = sprmPar<0x61, 0, SPRA::operand_1b_1>; // 0x2461
+using PFNoAllowOverlap = sprmPar<0x62, 0, SPRA::operand_1b_1>; // 0x2462
+using PWall = sprmPar<0x64, 1, SPRA::operand_1b_1>; // 0x2664
+using PIpgp = sprmPar<0x65, 0, SPRA::operand_4b_3>; // 0x6465
+using PCnf = sprmPar<0x66, 1, SPRA::operand_varlen_6>; // 0xC666
+using PRsid = sprmPar<0x67, 0, SPRA::operand_4b_3>; // 0x6467
+using PIstdListPermute = sprmPar<0x69, 1, SPRA::operand_varlen_6>; // 0xC669
+using PTableProps = sprmPar<0x6B, 0, SPRA::operand_4b_3>; // 0x646B
+using PTIstdInfo = sprmPar<0x6C, 1, SPRA::operand_varlen_6>; // 0xC66C
+using PFContextualSpacing = sprmPar<0x6D, 0, SPRA::operand_1b_1>; // 0x246D
+using PPropRMark = sprmPar<0x6F, 1, SPRA::operand_varlen_6>; // 0xC66F
+using PFMirrorIndents = sprmPar<0x70, 0, SPRA::operand_1b_1>; // 0x2470
+using PTtwo = sprmPar<0x71, 0, SPRA::operand_1b_1>; // 0x2471
// [MS-DOC] - v20170112 Section 2.6.3
-const sal_uInt16 sprmTJc90 = SPRM_TBL(0x00, 0, spra::operand_2b_2); // 0x5400
-const sal_uInt16 sprmTDxaLeft = SPRM_TBL(0x01, 1, spra::operand_2b_4); // 0x9601
-const sal_uInt16 sprmTDxaGapHalf = SPRM_TBL(0x02, 1, spra::operand_2b_4); // 0x9602
-const sal_uInt16 sprmTFCantSplit90 = SPRM_TBL(0x03, 0, spra::operand_1b_1); // 0x3403
-const sal_uInt16 sprmTTableHeader = SPRM_TBL(0x04, 0, spra::operand_1b_1); // 0x3404
-const sal_uInt16 sprmTTableBorders80 = SPRM_TBL(0x05, 1, spra::operand_varlen_6); // 0xD605
-const sal_uInt16 sprmTDyaRowHeight = SPRM_TBL(0x07, 0, spra::operand_2b_4); // 0x9407
-const sal_uInt16 sprmTDefTable = SPRM_TBL(0x08, 1, spra::operand_varlen_6); // 0xD608
-const sal_uInt16 sprmTDefTableShd80 = SPRM_TBL(0x09, 1, spra::operand_varlen_6); // 0xD609
-const sal_uInt16 sprmTTlp = SPRM_TBL(0x0A, 0, spra::operand_4b_3); // 0x740A
-const sal_uInt16 sprmTFBiDi = SPRM_TBL(0x0B, 1, spra::operand_2b_2); // 0x560B
-const sal_uInt16 sprmTDefTableShd3rd = SPRM_TBL(0x0C, 1, spra::operand_varlen_6); // 0xD60C
-const sal_uInt16 sprmTPc = SPRM_TBL(0x0D, 1, spra::operand_1b_1); // 0x360D
-const sal_uInt16 sprmTDxaAbs = SPRM_TBL(0x0E, 0, spra::operand_2b_4); // 0x940E
-const sal_uInt16 sprmTDyaAbs = SPRM_TBL(0x0F, 0, spra::operand_2b_4); // 0x940F
-const sal_uInt16 sprmTDxaFromText = SPRM_TBL(0x10, 0, spra::operand_2b_4); // 0x9410
-const sal_uInt16 sprmTDyaFromText = SPRM_TBL(0x11, 0, spra::operand_2b_4); // 0x9411
-const sal_uInt16 sprmTDefTableShd = SPRM_TBL(0x12, 1, spra::operand_varlen_6); // 0xD612
-const sal_uInt16 sprmTTableBorders = SPRM_TBL(0x13, 1, spra::operand_varlen_6); // 0xD613
-const sal_uInt16 sprmTTableWidth = SPRM_TBL(0x14, 1, spra::operand_3b_7); // 0xF614
-const sal_uInt16 sprmTFAutofit = SPRM_TBL(0x15, 1, spra::operand_1b_1); // 0x3615
-const sal_uInt16 sprmTDefTableShd2nd = SPRM_TBL(0x16, 1, spra::operand_varlen_6); // 0xD616
-const sal_uInt16 sprmTWidthBefore = SPRM_TBL(0x17, 1, spra::operand_3b_7); // 0xF617
-const sal_uInt16 sprmTWidthAfter = SPRM_TBL(0x18, 1, spra::operand_3b_7); // 0xF618
-const sal_uInt16 sprmTFKeepFollow = SPRM_TBL(0x19, 1, spra::operand_1b_1); // 0x3619
-const sal_uInt16 sprmTBrcTopCv = SPRM_TBL(0x1A, 1, spra::operand_varlen_6); // 0xD61A
-const sal_uInt16 sprmTBrcLeftCv = SPRM_TBL(0x1B, 1, spra::operand_varlen_6); // 0xD61B
-const sal_uInt16 sprmTBrcBottomCv = SPRM_TBL(0x1C, 1, spra::operand_varlen_6); // 0xD61C
-const sal_uInt16 sprmTBrcRightCv = SPRM_TBL(0x1D, 1, spra::operand_varlen_6); // 0xD61D
-const sal_uInt16 sprmTDxaFromTextRight = SPRM_TBL(0x1E, 0, spra::operand_2b_4); // 0x941E
-const sal_uInt16 sprmTDyaFromTextBottom = SPRM_TBL(0x1F, 0, spra::operand_2b_4); // 0x941F
-const sal_uInt16 sprmTSetBrc80 = SPRM_TBL(0x20, 1, spra::operand_varlen_6); // 0xD620
-const sal_uInt16 sprmTInsert = SPRM_TBL(0x21, 1, spra::operand_4b_3); // 0x7621
-const sal_uInt16 sprmTDelete = SPRM_TBL(0x22, 1, spra::operand_2b_2); // 0x5622
-const sal_uInt16 sprmTDxaCol = SPRM_TBL(0x23, 1, spra::operand_4b_3); // 0x7623
-const sal_uInt16 sprmTMerge = SPRM_TBL(0x24, 1, spra::operand_2b_2); // 0x5624
-const sal_uInt16 sprmTSplit = SPRM_TBL(0x25, 1, spra::operand_2b_2); // 0x5625
-const sal_uInt16 sprmTTextFlow = SPRM_TBL(0x29, 1, spra::operand_4b_3); // 0x7629
-const sal_uInt16 sprmTVertMerge = SPRM_TBL(0x2B, 1, spra::operand_varlen_6); // 0xD62B
-const sal_uInt16 sprmTVertAlign = SPRM_TBL(0x2C, 1, spra::operand_varlen_6); // 0xD62C
-const sal_uInt16 sprmTSetShd = SPRM_TBL(0x2D, 1, spra::operand_varlen_6); // 0xD62D
-const sal_uInt16 sprmTSetShdOdd = SPRM_TBL(0x2E, 1, spra::operand_varlen_6); // 0xD62E
-const sal_uInt16 sprmTSetBrc = SPRM_TBL(0x2F, 1, spra::operand_varlen_6); // 0xD62F
-const sal_uInt16 sprmTCellPadding = SPRM_TBL(0x32, 1, spra::operand_varlen_6); // 0xD632
-const sal_uInt16 sprmTCellSpacingDefault = SPRM_TBL(0x33, 1, spra::operand_varlen_6); // 0xD633
-const sal_uInt16 sprmTCellPaddingDefault = SPRM_TBL(0x34, 1, spra::operand_varlen_6); // 0xD634
-const sal_uInt16 sprmTCellWidth = SPRM_TBL(0x35, 1, spra::operand_varlen_6); // 0xD635
-const sal_uInt16 sprmTFitText = SPRM_TBL(0x36, 1, spra::operand_3b_7); // 0xF636
-const sal_uInt16 sprmTFCellNoWrap = SPRM_TBL(0x39, 1, spra::operand_varlen_6); // 0xD639
-const sal_uInt16 sprmTIstd = SPRM_TBL(0x3A, 1, spra::operand_2b_2); // 0x563A
-const sal_uInt16 sprmTCellPaddingStyle = SPRM_TBL(0x3E, 1, spra::operand_varlen_6); // 0xD63E
-const sal_uInt16 sprmTCellFHideMark = SPRM_TBL(0x42, 1, spra::operand_varlen_6); // 0xD642
-const sal_uInt16 sprmTSetShdTable = SPRM_TBL(0x60, 1, spra::operand_varlen_6); // 0xD660
-const sal_uInt16 sprmTWidthIndent = SPRM_TBL(0x61, 1, spra::operand_3b_7); // 0xF661
-const sal_uInt16 sprmTCellBrcType = SPRM_TBL(0x62, 1, spra::operand_varlen_6); // 0xD662
-const sal_uInt16 sprmTFBiDi90 = SPRM_TBL(0x64, 1, spra::operand_2b_2); // 0x5664
-const sal_uInt16 sprmTFNoAllowOverlap = SPRM_TBL(0x65, 0, spra::operand_1b_1); // 0x3465
-const sal_uInt16 sprmTFCantSplit = SPRM_TBL(0x66, 0, spra::operand_1b_1); // 0x3466
-const sal_uInt16 sprmTPropRMark = SPRM_TBL(0x67, 1, spra::operand_varlen_6); // 0xD667
-const sal_uInt16 sprmTWall = SPRM_TBL(0x68, 1, spra::operand_1b_1); // 0x3668
-const sal_uInt16 sprmTIpgp = SPRM_TBL(0x69, 0, spra::operand_4b_3); // 0x7469
-const sal_uInt16 sprmTCnf = SPRM_TBL(0x6A, 1, spra::operand_varlen_6); // 0xD66A
-const sal_uInt16 sprmTDefTableShdRaw = SPRM_TBL(0x70, 1, spra::operand_varlen_6); // 0xD670
-const sal_uInt16 sprmTDefTableShdRaw2nd = SPRM_TBL(0x71, 1, spra::operand_varlen_6); // 0xD671
-const sal_uInt16 sprmTDefTableShdRaw3rd = SPRM_TBL(0x72, 1, spra::operand_varlen_6); // 0xD672
-const sal_uInt16 sprmTRsid = SPRM_TBL(0x79, 0, spra::operand_4b_3); // 0x7479
-const sal_uInt16 sprmTCellVertAlignStyle = SPRM_TBL(0x7C, 0, spra::operand_1b_1); // 0x347C
-const sal_uInt16 sprmTCellNoWrapStyle = SPRM_TBL(0x7D, 0, spra::operand_1b_1); // 0x347D
-const sal_uInt16 sprmTCellBrcTopStyle = SPRM_TBL(0x7F, 0, spra::operand_varlen_6); // 0xD47F
-const sal_uInt16 sprmTCellBrcBottomStyle = SPRM_TBL(0x80, 1, spra::operand_varlen_6); // 0xD680
-const sal_uInt16 sprmTCellBrcLeftStyle = SPRM_TBL(0x81, 1, spra::operand_varlen_6); // 0xD681
-const sal_uInt16 sprmTCellBrcRightStyle = SPRM_TBL(0x82, 1, spra::operand_varlen_6); // 0xD682
-const sal_uInt16 sprmTCellBrcInsideHStyle = SPRM_TBL(0x83, 1, spra::operand_varlen_6); // 0xD683
-const sal_uInt16 sprmTCellBrcInsideVStyle = SPRM_TBL(0x84, 1, spra::operand_varlen_6); // 0xD684
-const sal_uInt16 sprmTCellBrcTL2BRStyle = SPRM_TBL(0x85, 1, spra::operand_varlen_6); // 0xD685
-const sal_uInt16 sprmTCellBrcTR2BLStyle = SPRM_TBL(0x86, 1, spra::operand_varlen_6); // 0xD686
-const sal_uInt16 sprmTCellShdStyle = SPRM_TBL(0x87, 1, spra::operand_varlen_6); // 0xD687
-const sal_uInt16 sprmTCHorzBands = SPRM_TBL(0x88, 0, spra::operand_1b_1); // 0x3488
-const sal_uInt16 sprmTCVertBands = SPRM_TBL(0x89, 0, spra::operand_1b_1); // 0x3489
-const sal_uInt16 sprmTJc = SPRM_TBL(0x8A, 0, spra::operand_2b_2); // 0x548A
+using TJc90 = sprmTbl<0x00, 0, SPRA::operand_2b_2>; // 0x5400
+using TDxaLeft = sprmTbl<0x01, 1, SPRA::operand_2b_4>; // 0x9601
+using TDxaGapHalf = sprmTbl<0x02, 1, SPRA::operand_2b_4>; // 0x9602
+using TFCantSplit90 = sprmTbl<0x03, 0, SPRA::operand_1b_1>; // 0x3403
+using TTableHeader = sprmTbl<0x04, 0, SPRA::operand_1b_1>; // 0x3404
+using TTableBorders80 = sprmTbl<0x05, 1, SPRA::operand_varlen_6>; // 0xD605
+using TDyaRowHeight = sprmTbl<0x07, 0, SPRA::operand_2b_4>; // 0x9407
+using TDefTable = sprmTbl<0x08, 1, SPRA::operand_varlen_6>; // 0xD608
+using TDefTableShd80 = sprmTbl<0x09, 1, SPRA::operand_varlen_6>; // 0xD609
+using TTlp = sprmTbl<0x0A, 0, SPRA::operand_4b_3>; // 0x740A
+using TFBiDi = sprmTbl<0x0B, 1, SPRA::operand_2b_2>; // 0x560B
+using TDefTableShd3rd = sprmTbl<0x0C, 1, SPRA::operand_varlen_6>; // 0xD60C
+using TPc = sprmTbl<0x0D, 1, SPRA::operand_1b_1>; // 0x360D
+using TDxaAbs = sprmTbl<0x0E, 0, SPRA::operand_2b_4>; // 0x940E
+using TDyaAbs = sprmTbl<0x0F, 0, SPRA::operand_2b_4>; // 0x940F
+using TDxaFromText = sprmTbl<0x10, 0, SPRA::operand_2b_4>; // 0x9410
+using TDyaFromText = sprmTbl<0x11, 0, SPRA::operand_2b_4>; // 0x9411
+using TDefTableShd = sprmTbl<0x12, 1, SPRA::operand_varlen_6>; // 0xD612
+using TTableBorders = sprmTbl<0x13, 1, SPRA::operand_varlen_6>; // 0xD613
+using TTableWidth = sprmTbl<0x14, 1, SPRA::operand_3b_7>; // 0xF614
+using TFAutofit = sprmTbl<0x15, 1, SPRA::operand_1b_1>; // 0x3615
+using TDefTableShd2nd = sprmTbl<0x16, 1, SPRA::operand_varlen_6>; // 0xD616
+using TWidthBefore = sprmTbl<0x17, 1, SPRA::operand_3b_7>; // 0xF617
+using TWidthAfter = sprmTbl<0x18, 1, SPRA::operand_3b_7>; // 0xF618
+using TFKeepFollow = sprmTbl<0x19, 1, SPRA::operand_1b_1>; // 0x3619
+using TBrcTopCv = sprmTbl<0x1A, 1, SPRA::operand_varlen_6>; // 0xD61A
+using TBrcLeftCv = sprmTbl<0x1B, 1, SPRA::operand_varlen_6>; // 0xD61B
+using TBrcBottomCv = sprmTbl<0x1C, 1, SPRA::operand_varlen_6>; // 0xD61C
+using TBrcRightCv = sprmTbl<0x1D, 1, SPRA::operand_varlen_6>; // 0xD61D
+using TDxaFromTextRight = sprmTbl<0x1E, 0, SPRA::operand_2b_4>; // 0x941E
+using TDyaFromTextBottom = sprmTbl<0x1F, 0, SPRA::operand_2b_4>; // 0x941F
+using TSetBrc80 = sprmTbl<0x20, 1, SPRA::operand_varlen_6>; // 0xD620
+using TInsert = sprmTbl<0x21, 1, SPRA::operand_4b_3>; // 0x7621
+using TDelete = sprmTbl<0x22, 1, SPRA::operand_2b_2>; // 0x5622
+using TDxaCol = sprmTbl<0x23, 1, SPRA::operand_4b_3>; // 0x7623
+using TMerge = sprmTbl<0x24, 1, SPRA::operand_2b_2>; // 0x5624
+using TSplit = sprmTbl<0x25, 1, SPRA::operand_2b_2>; // 0x5625
+using TTextFlow = sprmTbl<0x29, 1, SPRA::operand_4b_3>; // 0x7629
+using TVertMerge = sprmTbl<0x2B, 1, SPRA::operand_varlen_6>; // 0xD62B
+using TVertAlign = sprmTbl<0x2C, 1, SPRA::operand_varlen_6>; // 0xD62C
+using TSetShd = sprmTbl<0x2D, 1, SPRA::operand_varlen_6>; // 0xD62D
+using TSetShdOdd = sprmTbl<0x2E, 1, SPRA::operand_varlen_6>; // 0xD62E
+using TSetBrc = sprmTbl<0x2F, 1, SPRA::operand_varlen_6>; // 0xD62F
+using TCellPadding = sprmTbl<0x32, 1, SPRA::operand_varlen_6>; // 0xD632
+using TCellSpacingDefault = sprmTbl<0x33, 1, SPRA::operand_varlen_6>; // 0xD633
+using TCellPaddingDefault = sprmTbl<0x34, 1, SPRA::operand_varlen_6>; // 0xD634
+using TCellWidth = sprmTbl<0x35, 1, SPRA::operand_varlen_6>; // 0xD635
+using TFitText = sprmTbl<0x36, 1, SPRA::operand_3b_7>; // 0xF636
+using TFCellNoWrap = sprmTbl<0x39, 1, SPRA::operand_varlen_6>; // 0xD639
+using TIstd = sprmTbl<0x3A, 1, SPRA::operand_2b_2>; // 0x563A
+using TCellPaddingStyle = sprmTbl<0x3E, 1, SPRA::operand_varlen_6>; // 0xD63E
+using TCellFHideMark = sprmTbl<0x42, 1, SPRA::operand_varlen_6>; // 0xD642
+using TSetShdTable = sprmTbl<0x60, 1, SPRA::operand_varlen_6>; // 0xD660
+using TWidthIndent = sprmTbl<0x61, 1, SPRA::operand_3b_7>; // 0xF661
+using TCellBrcType = sprmTbl<0x62, 1, SPRA::operand_varlen_6>; // 0xD662
+using TFBiDi90 = sprmTbl<0x64, 1, SPRA::operand_2b_2>; // 0x5664
+using TFNoAllowOverlap = sprmTbl<0x65, 0, SPRA::operand_1b_1>; // 0x3465
+using TFCantSplit = sprmTbl<0x66, 0, SPRA::operand_1b_1>; // 0x3466
+using TPropRMark = sprmTbl<0x67, 1, SPRA::operand_varlen_6>; // 0xD667
+using TWall = sprmTbl<0x68, 1, SPRA::operand_1b_1>; // 0x3668
+using TIpgp = sprmTbl<0x69, 0, SPRA::operand_4b_3>; // 0x7469
+using TCnf = sprmTbl<0x6A, 1, SPRA::operand_varlen_6>; // 0xD66A
+using TDefTableShdRaw = sprmTbl<0x70, 1, SPRA::operand_varlen_6>; // 0xD670
+using TDefTableShdRaw2nd = sprmTbl<0x71, 1, SPRA::operand_varlen_6>; // 0xD671
+using TDefTableShdRaw3rd = sprmTbl<0x72, 1, SPRA::operand_varlen_6>; // 0xD672
+using TRsid = sprmTbl<0x79, 0, SPRA::operand_4b_3>; // 0x7479
+using TCellVertAlignStyle = sprmTbl<0x7C, 0, SPRA::operand_1b_1>; // 0x347C
+using TCellNoWrapStyle = sprmTbl<0x7D, 0, SPRA::operand_1b_1>; // 0x347D
+using TCellBrcTopStyle = sprmTbl<0x7F, 0, SPRA::operand_varlen_6>; // 0xD47F
+using TCellBrcBottomStyle = sprmTbl<0x80, 1, SPRA::operand_varlen_6>; // 0xD680
+using TCellBrcLeftStyle = sprmTbl<0x81, 1, SPRA::operand_varlen_6>; // 0xD681
+using TCellBrcRightStyle = sprmTbl<0x82, 1, SPRA::operand_varlen_6>; // 0xD682
+using TCellBrcInsideHStyle = sprmTbl<0x83, 1, SPRA::operand_varlen_6>; // 0xD683
+using TCellBrcInsideVStyle = sprmTbl<0x84, 1, SPRA::operand_varlen_6>; // 0xD684
+using TCellBrcTL2BRStyle = sprmTbl<0x85, 1, SPRA::operand_varlen_6>; // 0xD685
+using TCellBrcTR2BLStyle = sprmTbl<0x86, 1, SPRA::operand_varlen_6>; // 0xD686
+using TCellShdStyle = sprmTbl<0x87, 1, SPRA::operand_varlen_6>; // 0xD687
+using TCHorzBands = sprmTbl<0x88, 0, SPRA::operand_1b_1>; // 0x3488
+using TCVertBands = sprmTbl<0x89, 0, SPRA::operand_1b_1>; // 0x3489
+using TJc = sprmTbl<0x8A, 0, SPRA::operand_2b_2>; // 0x548A
// [MS-DOC] - v20170112 Section 2.6.4
-const sal_uInt16 sprmScnsPgn = SPRM_SEC(0x00, 0, spra::operand_1b_1); // 0x3000
-const sal_uInt16 sprmSiHeadingPgn = SPRM_SEC(0x01, 0, spra::operand_1b_1); // 0x3001
-const sal_uInt16 sprmSDxaColWidth = SPRM_SEC(0x03, 1, spra::operand_3b_7); // 0xF203
-const sal_uInt16 sprmSDxaColSpacing = SPRM_SEC(0x04, 1, spra::operand_3b_7); // 0xF204
-const sal_uInt16 sprmSFEvenlySpaced = SPRM_SEC(0x05, 0, spra::operand_1b_1); // 0x3005
-const sal_uInt16 sprmSFProtected = SPRM_SEC(0x06, 0, spra::operand_1b_1); // 0x3006
-const sal_uInt16 sprmSDmBinFirst = SPRM_SEC(0x07, 0, spra::operand_2b_2); // 0x5007
-const sal_uInt16 sprmSDmBinOther = SPRM_SEC(0x08, 0, spra::operand_2b_2); // 0x5008
-const sal_uInt16 sprmSBkc = SPRM_SEC(0x09, 0, spra::operand_1b_1); // 0x3009
-const sal_uInt16 sprmSFTitlePage = SPRM_SEC(0x0A, 0, spra::operand_1b_1); // 0x300A
-const sal_uInt16 sprmSCcolumns = SPRM_SEC(0x0B, 0, spra::operand_2b_2); // 0x500B
-const sal_uInt16 sprmSDxaColumns = SPRM_SEC(0x0C, 0, spra::operand_2b_4); // 0x900C
-const sal_uInt16 sprmSNfcPgn = SPRM_SEC(0x0E, 0, spra::operand_1b_1); // 0x300E
-const sal_uInt16 sprmSFPgnRestart = SPRM_SEC(0x11, 0, spra::operand_1b_1); // 0x3011
-const sal_uInt16 sprmSFEndnote = SPRM_SEC(0x12, 0, spra::operand_1b_1); // 0x3012
-const sal_uInt16 sprmSLnc = SPRM_SEC(0x13, 0, spra::operand_1b_1); // 0x3013
-const sal_uInt16 sprmSNLnnMod = SPRM_SEC(0x15, 0, spra::operand_2b_2); // 0x5015
-const sal_uInt16 sprmSDxaLnn = SPRM_SEC(0x16, 0, spra::operand_2b_4); // 0x9016
-const sal_uInt16 sprmSDyaHdrTop = SPRM_SEC(0x17, 0, spra::operand_2b_5); // 0xB017
-const sal_uInt16 sprmSDyaHdrBottom = SPRM_SEC(0x18, 0, spra::operand_2b_5); // 0xB018
-const sal_uInt16 sprmSLBetween = SPRM_SEC(0x19, 0, spra::operand_1b_1); // 0x3019
-const sal_uInt16 sprmSVjc = SPRM_SEC(0x1A, 0, spra::operand_1b_1); // 0x301A
-const sal_uInt16 sprmSLnnMin = SPRM_SEC(0x1B, 0, spra::operand_2b_2); // 0x501B
-const sal_uInt16 sprmSPgnStart97 = SPRM_SEC(0x1C, 0, spra::operand_2b_2); // 0x501C
-const sal_uInt16 sprmSBOrientation = SPRM_SEC(0x1D, 0, spra::operand_1b_1); // 0x301D
-const sal_uInt16 sprmSXaPage = SPRM_SEC(0x1F, 0, spra::operand_2b_5); // 0xB01F
-const sal_uInt16 sprmSYaPage = SPRM_SEC(0x20, 0, spra::operand_2b_5); // 0xB020
-const sal_uInt16 sprmSDxaLeft = SPRM_SEC(0x21, 0, spra::operand_2b_5); // 0xB021
-const sal_uInt16 sprmSDxaRight = SPRM_SEC(0x22, 0, spra::operand_2b_5); // 0xB022
-const sal_uInt16 sprmSDyaTop = SPRM_SEC(0x23, 0, spra::operand_2b_4); // 0x9023
-const sal_uInt16 sprmSDyaBottom = SPRM_SEC(0x24, 0, spra::operand_2b_4); // 0x9024
-const sal_uInt16 sprmSDzaGutter = SPRM_SEC(0x25, 0, spra::operand_2b_5); // 0xB025
-const sal_uInt16 sprmSDmPaperReq = SPRM_SEC(0x26, 0, spra::operand_2b_2); // 0x5026
-const sal_uInt16 sprmSFBiDi = SPRM_SEC(0x28, 1, spra::operand_1b_1); // 0x3228
-const sal_uInt16 sprmSFRTLGutter = SPRM_SEC(0x2A, 1, spra::operand_1b_1); // 0x322A
-const sal_uInt16 sprmSBrcTop80 = SPRM_SEC(0x2B, 0, spra::operand_4b_3); // 0x702B
-const sal_uInt16 sprmSBrcLeft80 = SPRM_SEC(0x2C, 0, spra::operand_4b_3); // 0x702C
-const sal_uInt16 sprmSBrcBottom80 = SPRM_SEC(0x2D, 0, spra::operand_4b_3); // 0x702D
-const sal_uInt16 sprmSBrcRight80 = SPRM_SEC(0x2E, 0, spra::operand_4b_3); // 0x702E
-const sal_uInt16 sprmSPgbProp = SPRM_SEC(0x2F, 1, spra::operand_2b_2); // 0x522F
-const sal_uInt16 sprmSDxtCharSpace = SPRM_SEC(0x30, 0, spra::operand_4b_3); // 0x7030
-const sal_uInt16 sprmSDyaLinePitch = SPRM_SEC(0x31, 0, spra::operand_2b_4); // 0x9031
-const sal_uInt16 sprmSClm = SPRM_SEC(0x32, 0, spra::operand_2b_2); // 0x5032
-const sal_uInt16 sprmSTextFlow = SPRM_SEC(0x33, 0, spra::operand_2b_2); // 0x5033
-const sal_uInt16 sprmSBrcTop = SPRM_SEC(0x34, 1, spra::operand_varlen_6); // 0xD234
-const sal_uInt16 sprmSBrcLeft = SPRM_SEC(0x35, 1, spra::operand_varlen_6); // 0xD235
-const sal_uInt16 sprmSBrcBottom = SPRM_SEC(0x36, 1, spra::operand_varlen_6); // 0xD236
-const sal_uInt16 sprmSBrcRight = SPRM_SEC(0x37, 1, spra::operand_varlen_6); // 0xD237
-const sal_uInt16 sprmSWall = SPRM_SEC(0x39, 1, spra::operand_1b_1); // 0x3239
-const sal_uInt16 sprmSRsid = SPRM_SEC(0x3A, 0, spra::operand_4b_3); // 0x703A
-const sal_uInt16 sprmSFpc = SPRM_SEC(0x3B, 0, spra::operand_1b_1); // 0x303B
-const sal_uInt16 sprmSRncFtn = SPRM_SEC(0x3C, 0, spra::operand_1b_1); // 0x303C
-const sal_uInt16 sprmSRncEdn = SPRM_SEC(0x3E, 0, spra::operand_1b_1); // 0x303E
-const sal_uInt16 sprmSNFtn = SPRM_SEC(0x3F, 0, spra::operand_2b_2); // 0x503F
-const sal_uInt16 sprmSNfcFtnRef = SPRM_SEC(0x40, 0, spra::operand_2b_2); // 0x5040
-const sal_uInt16 sprmSNEdn = SPRM_SEC(0x41, 0, spra::operand_2b_2); // 0x5041
-const sal_uInt16 sprmSNfcEdnRef = SPRM_SEC(0x42, 0, spra::operand_2b_2); // 0x5042
-const sal_uInt16 sprmSPropRMark = SPRM_SEC(0x43, 1, spra::operand_varlen_6); // 0xD243
-const sal_uInt16 sprmSPgnStart = SPRM_SEC(0x44, 0, spra::operand_4b_3); // 0x7044
+using ScnsPgn = sprmSec<0x00, 0, SPRA::operand_1b_1>; // 0x3000
+using SiHeadingPgn = sprmSec<0x01, 0, SPRA::operand_1b_1>; // 0x3001
+using SDxaColWidth = sprmSec<0x03, 1, SPRA::operand_3b_7>; // 0xF203
+using SDxaColSpacing = sprmSec<0x04, 1, SPRA::operand_3b_7>; // 0xF204
+using SFEvenlySpaced = sprmSec<0x05, 0, SPRA::operand_1b_1>; // 0x3005
+using SFProtected = sprmSec<0x06, 0, SPRA::operand_1b_1>; // 0x3006
+using SDmBinFirst = sprmSec<0x07, 0, SPRA::operand_2b_2>; // 0x5007
+using SDmBinOther = sprmSec<0x08, 0, SPRA::operand_2b_2>; // 0x5008
+using SBkc = sprmSec<0x09, 0, SPRA::operand_1b_1>; // 0x3009
+using SFTitlePage = sprmSec<0x0A, 0, SPRA::operand_1b_1>; // 0x300A
+using SCcolumns = sprmSec<0x0B, 0, SPRA::operand_2b_2>; // 0x500B
+using SDxaColumns = sprmSec<0x0C, 0, SPRA::operand_2b_4>; // 0x900C
+using SNfcPgn = sprmSec<0x0E, 0, SPRA::operand_1b_1>; // 0x300E
+using SFPgnRestart = sprmSec<0x11, 0, SPRA::operand_1b_1>; // 0x3011
+using SFEndnote = sprmSec<0x12, 0, SPRA::operand_1b_1>; // 0x3012
+using SLnc = sprmSec<0x13, 0, SPRA::operand_1b_1>; // 0x3013
+using SNLnnMod = sprmSec<0x15, 0, SPRA::operand_2b_2>; // 0x5015
+using SDxaLnn = sprmSec<0x16, 0, SPRA::operand_2b_4>; // 0x9016
+using SDyaHdrTop = sprmSec<0x17, 0, SPRA::operand_2b_5>; // 0xB017
+using SDyaHdrBottom = sprmSec<0x18, 0, SPRA::operand_2b_5>; // 0xB018
+using SLBetween = sprmSec<0x19, 0, SPRA::operand_1b_1>; // 0x3019
+using SVjc = sprmSec<0x1A, 0, SPRA::operand_1b_1>; // 0x301A
+using SLnnMin = sprmSec<0x1B, 0, SPRA::operand_2b_2>; // 0x501B
+using SPgnStart97 = sprmSec<0x1C, 0, SPRA::operand_2b_2>; // 0x501C
+using SBOrientation = sprmSec<0x1D, 0, SPRA::operand_1b_1>; // 0x301D
+using SXaPage = sprmSec<0x1F, 0, SPRA::operand_2b_5>; // 0xB01F
+using SYaPage = sprmSec<0x20, 0, SPRA::operand_2b_5>; // 0xB020
+using SDxaLeft = sprmSec<0x21, 0, SPRA::operand_2b_5>; // 0xB021
+using SDxaRight = sprmSec<0x22, 0, SPRA::operand_2b_5>; // 0xB022
+using SDyaTop = sprmSec<0x23, 0, SPRA::operand_2b_4>; // 0x9023
+using SDyaBottom = sprmSec<0x24, 0, SPRA::operand_2b_4>; // 0x9024
+using SDzaGutter = sprmSec<0x25, 0, SPRA::operand_2b_5>; // 0xB025
+using SDmPaperReq = sprmSec<0x26, 0, SPRA::operand_2b_2>; // 0x5026
+using SFBiDi = sprmSec<0x28, 1, SPRA::operand_1b_1>; // 0x3228
+using SFRTLGutter = sprmSec<0x2A, 1, SPRA::operand_1b_1>; // 0x322A
+using SBrcTop80 = sprmSec<0x2B, 0, SPRA::operand_4b_3>; // 0x702B
+using SBrcLeft80 = sprmSec<0x2C, 0, SPRA::operand_4b_3>; // 0x702C
+using SBrcBottom80 = sprmSec<0x2D, 0, SPRA::operand_4b_3>; // 0x702D
+using SBrcRight80 = sprmSec<0x2E, 0, SPRA::operand_4b_3>; // 0x702E
+using SPgbProp = sprmSec<0x2F, 1, SPRA::operand_2b_2>; // 0x522F
+using SDxtCharSpace = sprmSec<0x30, 0, SPRA::operand_4b_3>; // 0x7030
+using SDyaLinePitch = sprmSec<0x31, 0, SPRA::operand_2b_4>; // 0x9031
+using SClm = sprmSec<0x32, 0, SPRA::operand_2b_2>; // 0x5032
+using STextFlow = sprmSec<0x33, 0, SPRA::operand_2b_2>; // 0x5033
+using SBrcTop = sprmSec<0x34, 1, SPRA::operand_varlen_6>; // 0xD234
+using SBrcLeft = sprmSec<0x35, 1, SPRA::operand_varlen_6>; // 0xD235
+using SBrcBottom = sprmSec<0x36, 1, SPRA::operand_varlen_6>; // 0xD236
+using SBrcRight = sprmSec<0x37, 1, SPRA::operand_varlen_6>; // 0xD237
+using SWall = sprmSec<0x39, 1, SPRA::operand_1b_1>; // 0x3239
+using SRsid = sprmSec<0x3A, 0, SPRA::operand_4b_3>; // 0x703A
+using SFpc = sprmSec<0x3B, 0, SPRA::operand_1b_1>; // 0x303B
+using SRncFtn = sprmSec<0x3C, 0, SPRA::operand_1b_1>; // 0x303C
+using SRncEdn = sprmSec<0x3E, 0, SPRA::operand_1b_1>; // 0x303E
+using SNFtn = sprmSec<0x3F, 0, SPRA::operand_2b_2>; // 0x503F
+using SNfcFtnRef = sprmSec<0x40, 0, SPRA::operand_2b_2>; // 0x5040
+using SNEdn = sprmSec<0x41, 0, SPRA::operand_2b_2>; // 0x5041
+using SNfcEdnRef = sprmSec<0x42, 0, SPRA::operand_2b_2>; // 0x5042
+using SPropRMark = sprmSec<0x43, 1, SPRA::operand_varlen_6>; // 0xD243
+using SPgnStart = sprmSec<0x44, 0, SPRA::operand_4b_3>; // 0x7044
// [MS-DOC] - v20170112 Section 2.6.5
-const sal_uInt16 sprmPicBrcTop80 = SPRM_PIC(0x02, 0, spra::operand_4b_3); // 0x6C02
-const sal_uInt16 sprmPicBrcLeft80 = SPRM_PIC(0x03, 0, spra::operand_4b_3); // 0x6C03
-const sal_uInt16 sprmPicBrcBottom80 = SPRM_PIC(0x04, 0, spra::operand_4b_3); // 0x6C04
-const sal_uInt16 sprmPicBrcRight80 = SPRM_PIC(0x05, 0, spra::operand_4b_3); // 0x6C05
-const sal_uInt16 sprmPicBrcTop = SPRM_PIC(0x08, 1, spra::operand_varlen_6); // 0xCE08
-const sal_uInt16 sprmPicBrcLeft = SPRM_PIC(0x09, 1, spra::operand_varlen_6); // 0xCE09
-const sal_uInt16 sprmPicBrcBottom = SPRM_PIC(0x0A, 1, spra::operand_varlen_6); // 0xCE0A
-const sal_uInt16 sprmPicBrcRight = SPRM_PIC(0x0B, 1, spra::operand_varlen_6); // 0xCE0B
+using PicBrcTop80 = sprmPic<0x02, 0, SPRA::operand_4b_3>; // 0x6C02
+using PicBrcLeft80 = sprmPic<0x03, 0, SPRA::operand_4b_3>; // 0x6C03
+using PicBrcBottom80 = sprmPic<0x04, 0, SPRA::operand_4b_3>; // 0x6C04
+using PicBrcRight80 = sprmPic<0x05, 0, SPRA::operand_4b_3>; // 0x6C05
+using PicBrcTop = sprmPic<0x08, 1, SPRA::operand_varlen_6>; // 0xCE08
+using PicBrcLeft = sprmPic<0x09, 1, SPRA::operand_varlen_6>; // 0xCE09
+using PicBrcBottom = sprmPic<0x0A, 1, SPRA::operand_varlen_6>; // 0xCE0A
+using PicBrcRight = sprmPic<0x0B, 1, SPRA::operand_varlen_6>; // 0xCE0B
}
#endif // INCLUDED_SW_SOURCE_FILTER_WW8_SPRMIDS_HXX
diff --git a/sw/source/filter/ww8/wrtw8nds.cxx b/sw/source/filter/ww8/wrtw8nds.cxx
index 4df9bd3f9761..86e884fc8794 100644
--- a/sw/source/filter/ww8/wrtw8nds.cxx
+++ b/sw/source/filter/ww8/wrtw8nds.cxx
@@ -1247,7 +1247,7 @@ void WW8AttributeOutput::FieldVanish( const OUString& rText, ww::eField /*eType*
m_rWW8Export.GetCurrentItems( aItems );
// sprmCFFieldVanish
- SwWW8Writer::InsUInt16( aItems, NS_sprm::sprmCFFldVanish );
+ SwWW8Writer::InsUInt16( aItems, NS_sprm::CFFldVanish::val );
aItems.push_back( 1 );
sal_uInt16 nStt_sprmCFSpec = aItems.size();
@@ -1822,22 +1822,22 @@ void WW8AttributeOutput::FormatDrop( const SwTextNode& rNode, const SwFormatDrop
ShortToSVBT16( nStyle, nSty );
m_rWW8Export.pO->insert( m_rWW8Export.pO->end(), nSty, nSty+2 ); // Style #
- m_rWW8Export.InsUInt16( NS_sprm::sprmPPc ); // Alignment (sprmPPc)
+ m_rWW8Export.InsUInt16( NS_sprm::PPc::val ); // Alignment (sprmPPc)
m_rWW8Export.pO->push_back( 0x20 );
- m_rWW8Export.InsUInt16( NS_sprm::sprmPWr ); // Wrapping (sprmPWr)
+ m_rWW8Export.InsUInt16( NS_sprm::PWr::val ); // Wrapping (sprmPWr)
m_rWW8Export.pO->push_back( 0x02 );
- m_rWW8Export.InsUInt16( NS_sprm::sprmPDcs ); // Dropcap (sprmPDcs)
+ m_rWW8Export.InsUInt16( NS_sprm::PDcs::val ); // Dropcap (sprmPDcs)
int nDCS = ( nDropLines << 3 ) | 0x01;
m_rWW8Export.InsUInt16( static_cast< sal_uInt16 >( nDCS ) );
- m_rWW8Export.InsUInt16( NS_sprm::sprmPDxaFromText ); // Distance from text (sprmPDxaFromText)
+ m_rWW8Export.InsUInt16( NS_sprm::PDxaFromText::val ); // Distance from text (sprmPDxaFromText)
m_rWW8Export.InsUInt16( nDistance );
if ( rNode.GetDropSize( rFontHeight, rDropHeight, rDropDescent ) )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPDyaLine ); // Line spacing
+ m_rWW8Export.InsUInt16( NS_sprm::PDyaLine::val ); // Line spacing
m_rWW8Export.InsUInt16( static_cast< sal_uInt16 >( -rDropHeight ) );
m_rWW8Export.InsUInt16( 0 );
}
@@ -1860,14 +1860,14 @@ void WW8AttributeOutput::FormatDrop( const SwTextNode& rNode, const SwFormatDrop
const SwCharFormat *pSwCharFormat = rSwFormatDrop.GetCharFormat();
if ( pSwCharFormat )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCIstd );
+ m_rWW8Export.InsUInt16( NS_sprm::CIstd::val );
m_rWW8Export.InsUInt16( m_rWW8Export.GetId( pSwCharFormat ) );
}
- m_rWW8Export.InsUInt16( NS_sprm::sprmCHpsPos ); // Lower the chars
+ m_rWW8Export.InsUInt16( NS_sprm::CHpsPos::val ); // Lower the chars
m_rWW8Export.InsUInt16( static_cast< sal_uInt16 >( -((nDropLines - 1)*rDropDescent) / 10 ) );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCHps ); // Font Size
+ m_rWW8Export.InsUInt16( NS_sprm::CHps::val ); // Font Size
m_rWW8Export.InsUInt16( static_cast< sal_uInt16 >( rFontHeight / 10 ) );
}
@@ -3422,12 +3422,12 @@ void WW8AttributeOutput::Redline( const SwRedlineData* pRedline )
static const sal_uInt16 insSprmIds[ 3 ] =
{
// Ids for insert // for WW8
- NS_sprm::sprmCFRMarkIns, NS_sprm::sprmCIbstRMark, NS_sprm::sprmCDttmRMark,
+ NS_sprm::CFRMarkIns::val, NS_sprm::CIbstRMark::val, NS_sprm::CDttmRMark::val,
};
static const sal_uInt16 delSprmIds[ 3 ] =
{
// Ids for delete // for WW8
- NS_sprm::sprmCFRMarkDel, NS_sprm::sprmCIbstRMarkDel, NS_sprm::sprmCDttmRMarkDel,
+ NS_sprm::CFRMarkDel::val, NS_sprm::CIbstRMarkDel::val, NS_sprm::CDttmRMarkDel::val,
};
const sal_uInt16* pSprmIds = nullptr;
@@ -3442,7 +3442,7 @@ void WW8AttributeOutput::Redline( const SwRedlineData* pRedline )
break;
case RedlineType::Format:
- m_rWW8Export.InsUInt16( NS_sprm::sprmCPropRMark90 );
+ m_rWW8Export.InsUInt16( NS_sprm::CPropRMark90::val );
m_rWW8Export.pO->push_back( 7 ); // len
m_rWW8Export.pO->push_back( 1 );
m_rWW8Export.InsUInt16( m_rWW8Export.AddRedlineAuthor( pRedline->GetAuthor() ) );
diff --git a/sw/source/filter/ww8/wrtw8num.cxx b/sw/source/filter/ww8/wrtw8num.cxx
index df51bb99be36..3efd99cdcb92 100644
--- a/sw/source/filter/ww8/wrtw8num.cxx
+++ b/sw/source/filter/ww8/wrtw8num.cxx
@@ -351,9 +351,9 @@ void WW8AttributeOutput::NumberingLevel( sal_uInt8 /*nLevel*/,
{
sal_uInt16 nFontID = m_rWW8Export.m_aFontHelper.GetId( *pFont );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCRgFtc0 );
+ m_rWW8Export.InsUInt16( NS_sprm::CRgFtc0::val );
m_rWW8Export.InsUInt16( nFontID );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCRgFtc2 );
+ m_rWW8Export.InsUInt16( NS_sprm::CRgFtc2::val );
m_rWW8Export.InsUInt16( nFontID );
}
@@ -364,9 +364,9 @@ void WW8AttributeOutput::NumberingLevel( sal_uInt8 /*nLevel*/,
int nIndex = m_rWW8Export.GetGrfIndex(*pBrush);
if ( nIndex != -1 )
{
- m_rWW8Export.InsUInt16(NS_sprm::sprmCPbiIBullet);
+ m_rWW8Export.InsUInt16(NS_sprm::CPbiIBullet::val);
m_rWW8Export.InsUInt32(nIndex);
- m_rWW8Export.InsUInt16(NS_sprm::sprmCPbiGrf);
+ m_rWW8Export.InsUInt16(NS_sprm::CPbiGrf::val);
m_rWW8Export.InsUInt16(1);
}
}
diff --git a/sw/source/filter/ww8/wrtw8sty.cxx b/sw/source/filter/ww8/wrtw8sty.cxx
index bfd251918c77..2172f2c3e54d 100644
--- a/sw/source/filter/ww8/wrtw8sty.cxx
+++ b/sw/source/filter/ww8/wrtw8sty.cxx
@@ -1331,7 +1331,7 @@ void WW8AttributeOutput::SectFootnoteEndnotePr()
{
const SwFootnoteInfo& rInfo = m_rWW8Export.m_pDoc->GetFootnoteInfo();
const SwEndNoteInfo& rEndNoteInfo = m_rWW8Export.m_pDoc->GetEndNoteInfo();
- m_rWW8Export.InsUInt16( NS_sprm::sprmSRncFtn );
+ m_rWW8Export.InsUInt16( NS_sprm::SRncFtn::val );
switch( rInfo.m_eNum )
{
case FTNNUM_PAGE: m_rWW8Export.pO->push_back( sal_uInt8/*rncRstPage*/ (2) ); break;
@@ -1339,10 +1339,10 @@ void WW8AttributeOutput::SectFootnoteEndnotePr()
default: m_rWW8Export.pO->push_back( sal_uInt8/*rncCont*/ (0) ); break;
}
- m_rWW8Export.InsUInt16(NS_sprm::sprmSNfcFtnRef);
+ m_rWW8Export.InsUInt16(NS_sprm::SNfcFtnRef::val);
sal_uInt8 nId = WW8Export::GetNumId(rInfo.m_aFormat.GetNumberingType());
SwWW8Writer::InsUInt16(*m_rWW8Export.pO, nId);
- m_rWW8Export.InsUInt16(NS_sprm::sprmSNfcEdnRef);
+ m_rWW8Export.InsUInt16(NS_sprm::SNfcEdnRef::val);
nId = WW8Export::GetNumId(rEndNoteInfo.m_aFormat.GetNumberingType());
SwWW8Writer::InsUInt16(*m_rWW8Export.pO, nId);
}
@@ -1353,7 +1353,7 @@ void WW8AttributeOutput::SectionFormProtection( bool bProtected )
//is not protected, set the unlocked flag
if ( m_rWW8Export.pSepx->DocumentIsProtected() && !bProtected )
{
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSFProtected );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SFProtected::val );
m_rWW8Export.pO->push_back( 1 );
}
}
@@ -1361,24 +1361,24 @@ void WW8AttributeOutput::SectionFormProtection( bool bProtected )
void WW8AttributeOutput::SectionLineNumbering( sal_uLong nRestartNo, const SwLineNumberInfo& rLnNumInfo )
{
// sprmSNLnnMod - activate Line Numbering and define Modulo
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSNLnnMod );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SNLnnMod::val );
SwWW8Writer::InsUInt16( *m_rWW8Export.pO, rLnNumInfo.GetCountBy() );
// sprmSDxaLnn - xPosition of Line Number
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSDxaLnn );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SDxaLnn::val );
SwWW8Writer::InsUInt16( *m_rWW8Export.pO, rLnNumInfo.GetPosFromLeft() );
// sprmSLnc - restart number: 0 per page, 1 per section, 2 never restart
if ( nRestartNo || !rLnNumInfo.IsRestartEachPage() )
{
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSLnc );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SLnc::val );
m_rWW8Export.pO->push_back( nRestartNo ? 1 : 2 );
}
// sprmSLnnMin - Restart the Line Number with given value
if ( nRestartNo )
{
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSLnnMin );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SLnnMin::val );
SwWW8Writer::InsUInt16( *m_rWW8Export.pO, static_cast<sal_uInt16>(nRestartNo) - 1 );
}
}
@@ -1386,7 +1386,7 @@ void WW8AttributeOutput::SectionLineNumbering( sal_uLong nRestartNo, const SwLin
void WW8AttributeOutput::SectionTitlePage()
{
// sprmSFTitlePage
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSFTitlePage );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SFTitlePage::val );
m_rWW8Export.pO->push_back( 1 );
}
@@ -1417,14 +1417,14 @@ void WW8AttributeOutput::SectionPageBorders( const SwFrameFormat* pPdFormat, con
if ( USHRT_MAX != nPgBorder )
{
// write the Flag and Border Attribute
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSPgbProp );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SPgbProp::val );
SwWW8Writer::InsUInt16( *m_rWW8Export.pO, nPgBorder );
}
}
void WW8AttributeOutput::SectionBiDi( bool bBiDi )
{
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSFBiDi );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SFBiDi::val );
m_rWW8Export.pO->push_back( bBiDi? 1: 0 );
}
@@ -1432,17 +1432,17 @@ void WW8AttributeOutput::SectionPageNumbering( sal_uInt16 nNumType, const ::std:
{
// sprmSNfcPgn
sal_uInt8 nb = WW8Export::GetNumId( nNumType );
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSNfcPgn );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SNfcPgn::val );
m_rWW8Export.pO->push_back( nb );
if ( oPageRestartNumber )
{
// sprmSFPgnRestart
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSFPgnRestart );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SFPgnRestart::val );
m_rWW8Export.pO->push_back( 1 );
// sprmSPgnStart
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSPgnStart97 );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SPgnStart97::val );
SwWW8Writer::InsUInt16( *m_rWW8Export.pO, *oPageRestartNumber );
}
}
@@ -1451,7 +1451,7 @@ void WW8AttributeOutput::SectionType( sal_uInt8 nBreakCode )
{
if ( 2 != nBreakCode ) // new page is the default
{
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSBkc );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SBkc::val );
m_rWW8Export.pO->push_back( nBreakCode );
}
}
@@ -1495,7 +1495,7 @@ void WW8AttributeOutput::TextVerticalAdjustment( const drawing::TextVerticalAdju
default:
break;
}
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmSVjc );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::SVjc::val );
m_rWW8Export.pO->push_back( nMSVA );
}
}
diff --git a/sw/source/filter/ww8/wrtww8.cxx b/sw/source/filter/ww8/wrtww8.cxx
index bd71f59d7357..c22eae519943 100644
--- a/sw/source/filter/ww8/wrtww8.cxx
+++ b/sw/source/filter/ww8/wrtww8.cxx
@@ -1807,7 +1807,7 @@ void WW8Export::WriteStringAsPara( const OUString& rText )
if( m_bOutTable )
{ // Tab-Attr
// sprmPFInTable
- SwWW8Writer::InsUInt16( aArr, NS_sprm::sprmPFInTable );
+ SwWW8Writer::InsUInt16( aArr, NS_sprm::PFInTable::val );
aArr.push_back( 1 );
}
@@ -2006,14 +2006,14 @@ void WW8AttributeOutput::TableInfoCell( ww8::WW8TableNodeInfoInner::Pointer_t pT
if ( nDepth > 0 )
{
/* Cell */
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFInTable );
+ m_rWW8Export.InsUInt16( NS_sprm::PFInTable::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x1) );
- m_rWW8Export.InsUInt16( NS_sprm::sprmPItap );
+ m_rWW8Export.InsUInt16( NS_sprm::PItap::val );
m_rWW8Export.InsUInt32( nDepth );
if ( nDepth > 1 && pTableTextNodeInfoInner->isEndOfCell() )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFInnerTableCell );
+ m_rWW8Export.InsUInt16( NS_sprm::PFInnerTableCell::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x1) );
}
}
@@ -2028,23 +2028,23 @@ void WW8AttributeOutput::TableInfoRow( ww8::WW8TableNodeInfoInner::Pointer_t pTa
/* Row */
if ( pTableTextNodeInfoInner->isEndOfLine() )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFInTable );
+ m_rWW8Export.InsUInt16( NS_sprm::PFInTable::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x1) );
if ( nDepth == 1 )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFTtp );
+ m_rWW8Export.InsUInt16( NS_sprm::PFTtp::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x1) );
}
- m_rWW8Export.InsUInt16( NS_sprm::sprmPItap );
+ m_rWW8Export.InsUInt16( NS_sprm::PItap::val );
m_rWW8Export.InsUInt32( nDepth );
if ( nDepth > 1 )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFInnerTableCell );
+ m_rWW8Export.InsUInt16( NS_sprm::PFInnerTableCell::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x1) );
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFInnerTtp );
+ m_rWW8Export.InsUInt16( NS_sprm::PFInnerTtp::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x1) );
}
@@ -2147,7 +2147,7 @@ void WW8AttributeOutput::TableVerticalCell( ww8::WW8TableNodeInfoInner::Pointer_
if (nTextFlow != 0)
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTTextFlow );
+ m_rWW8Export.InsUInt16( NS_sprm::TTextFlow::val );
m_rWW8Export.pO->push_back( n ); //start range
m_rWW8Export.pO->push_back( sal_uInt8(n + 1) ); //end range
m_rWW8Export.InsUInt16(nTextFlow);
@@ -2169,9 +2169,9 @@ void WW8AttributeOutput::TableCanSplit( ww8::WW8TableNodeInfoInner::Pointer_t pT
const SwFormatRowSplit& rSplittable = pLineFormat->GetRowSplit();
sal_uInt8 nCantSplit = (!rSplittable.GetValue()) ? 1 : 0;
- m_rWW8Export.InsUInt16( NS_sprm::sprmTFCantSplit );
+ m_rWW8Export.InsUInt16( NS_sprm::TFCantSplit::val );
m_rWW8Export.pO->push_back( nCantSplit );
- m_rWW8Export.InsUInt16( NS_sprm::sprmTFCantSplit90 ); // also write fCantSplit90
+ m_rWW8Export.InsUInt16( NS_sprm::TFCantSplit90::val ); // also write fCantSplit90
m_rWW8Export.pO->push_back( nCantSplit );
}
@@ -2182,7 +2182,7 @@ void WW8AttributeOutput::TableBidi( ww8::WW8TableNodeInfoInner::Pointer_t pTable
if ( m_rWW8Export.TrueFrameDirection(*pFrameFormat) == SvxFrameDirection::Horizontal_RL_TB )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTFBiDi );
+ m_rWW8Export.InsUInt16( NS_sprm::TFBiDi::val );
m_rWW8Export.InsUInt16( 1 );
}
}
@@ -2214,7 +2214,7 @@ void WW8AttributeOutput::TableHeight( ww8::WW8TableNodeInfoInner::Pointer_t pTab
if ( nHeight )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTDyaRowHeight );
+ m_rWW8Export.InsUInt16( NS_sprm::TDyaRowHeight::val );
m_rWW8Export.InsUInt16( static_cast<sal_uInt16>(nHeight) );
}
@@ -2247,24 +2247,24 @@ void WW8AttributeOutput::TableOrientation( ww8::WW8TableNodeInfoInner::Pointer_t
switch (eHOri)
{
case text::HoriOrientation::CENTER:
- m_rWW8Export.InsUInt16( NS_sprm::sprmTJc ); //logical orientation required for MSO
+ m_rWW8Export.InsUInt16( NS_sprm::TJc::val ); //logical orientation required for MSO
m_rWW8Export.InsUInt16( 1 );
- m_rWW8Export.InsUInt16( NS_sprm::sprmTJc90 ); //physical orientation required for LO
+ m_rWW8Export.InsUInt16( NS_sprm::TJc90::val ); //physical orientation required for LO
m_rWW8Export.InsUInt16( 1 );
break;
case text::HoriOrientation::RIGHT:
- m_rWW8Export.InsUInt16( NS_sprm::sprmTJc90 ); //required for LO
+ m_rWW8Export.InsUInt16( NS_sprm::TJc90::val ); //required for LO
m_rWW8Export.InsUInt16( 2 );
if ( !bIsRTL )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTJc ); //required for MSO
+ m_rWW8Export.InsUInt16( NS_sprm::TJc::val ); //required for MSO
m_rWW8Export.InsUInt16( 2 );
}
break;
case text::HoriOrientation::LEFT:
if ( bIsRTL )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTJc ); //required for MSO
+ m_rWW8Export.InsUInt16( NS_sprm::TJc::val ); //required for MSO
m_rWW8Export.InsUInt16( 2 );
}
break;
@@ -2272,7 +2272,7 @@ void WW8AttributeOutput::TableOrientation( ww8::WW8TableNodeInfoInner::Pointer_t
// Width can only be specified for the LOGICAL left, so in RTL, that is always PHYSICAL right
if ( bIsRTL )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTJc90 ); //required for LO
+ m_rWW8Export.InsUInt16( NS_sprm::TJc90::val ); //required for LO
m_rWW8Export.InsUInt16( 2 );
}
break;
@@ -2302,19 +2302,19 @@ void WW8AttributeOutput::TableSpacing(ww8::WW8TableNodeInfoInner::Pointer_t pTab
sal_uInt8 const nTPc = (nPadding << 4) | (nPcVert << 2) | nPcHorz;
- m_rWW8Export.InsUInt16(NS_sprm::sprmTPc);
+ m_rWW8Export.InsUInt16(NS_sprm::TPc::val);
m_rWW8Export.pO->push_back( nTPc );
- m_rWW8Export.InsUInt16(NS_sprm::sprmTDyaAbs);
+ m_rWW8Export.InsUInt16(NS_sprm::TDyaAbs::val);
m_rWW8Export.InsUInt16(rUL.GetUpper());
- m_rWW8Export.InsUInt16(NS_sprm::sprmTDyaFromText);
+ m_rWW8Export.InsUInt16(NS_sprm::TDyaFromText::val);
m_rWW8Export.InsUInt16(rUL.GetUpper());
}
if (rUL.GetLower() > 0)
{
- m_rWW8Export.InsUInt16(NS_sprm::sprmTDyaFromTextBottom);
+ m_rWW8Export.InsUInt16(NS_sprm::TDyaFromTextBottom::val);
m_rWW8Export.InsUInt16(rUL.GetLower());
}
}
@@ -2326,7 +2326,7 @@ void WW8AttributeOutput::TableDefinition( ww8::WW8TableNodeInfoInner::Pointer_t
if ( pTable->GetRowsToRepeat() > pTableTextNodeInfoInner->getRow() )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTTableHeader );
+ m_rWW8Export.InsUInt16( NS_sprm::TTableHeader::val );
m_rWW8Export.pO->push_back( 1 );
}
@@ -2337,7 +2337,7 @@ void WW8AttributeOutput::TableDefinition( ww8::WW8TableNodeInfoInner::Pointer_t
assert(nBoxes <= ww8::MAXTABLECELLS);
// sprm header
- m_rWW8Export.InsUInt16( NS_sprm::sprmTDefTable );
+ m_rWW8Export.InsUInt16( NS_sprm::TDefTable::val );
sal_uInt16 nSprmSize = 2 + (nBoxes + 1) * 2 + nBoxes * 20;
m_rWW8Export.InsUInt16( nSprmSize ); // length
@@ -2440,7 +2440,7 @@ void WW8AttributeOutput::TableDefinition( ww8::WW8TableNodeInfoInner::Pointer_t
// Width is in fiftieths of a percent. For sprmTTableWidth, must be non-negative and 600% max
if ( nWidthPercent > 0 && nWidthPercent <= 600 )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmTTableWidth );
+ m_rWW8Export.InsUInt16( NS_sprm::TTableWidth::val );
m_rWW8Export.pO->push_back( sal_uInt8/*ftsPercent*/ (2) );
m_rWW8Export.InsUInt16( static_cast<sal_uInt16>(nWidthPercent) * 50 );
}
@@ -2551,7 +2551,7 @@ void WW8AttributeOutput::TableDefaultBorders( ww8::WW8TableNodeInfoInner::Pointe
// Set row default cell margins using this last cell in the row
for ( int i = 0; i < 4; ++i )
{
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmTCellPaddingDefault );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::TCellPaddingDefault::val );
m_rWW8Export.pO->push_back( sal_uInt8(6) );
m_rWW8Export.pO->push_back( sal_uInt8(0) );
m_rWW8Export.pO->push_back( sal_uInt8(1) );
@@ -2632,7 +2632,7 @@ void WW8AttributeOutput::TableCellBorders(
{
if ( nSideBits[i] )
{
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmTCellPadding );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::TCellPadding::val );
m_rWW8Export.pO->push_back( sal_uInt8(6) ); // 6 bytes
m_rWW8Export.pO->push_back( sal_uInt8(nSeqStart) ); // first cell: apply margin
m_rWW8Export.pO->push_back( sal_uInt8(n) ); // end cell: do not apply margin
@@ -2656,7 +2656,7 @@ void WW8AttributeOutput::TableBackgrounds( ww8::WW8TableNodeInfoInner::Pointer_t
const SwTableBoxes & rTabBoxes = pTabLine->GetTabBoxes();
sal_uInt8 nBoxes = rTabBoxes.size();
- m_rWW8Export.InsUInt16( NS_sprm::sprmTDefTableShd80 );
+ m_rWW8Export.InsUInt16( NS_sprm::TDefTableShd80::val );
m_rWW8Export.pO->push_back( static_cast<sal_uInt8>(nBoxes * 2) ); // Len
Color aRowColor = COL_AUTO;
@@ -2683,8 +2683,8 @@ void WW8AttributeOutput::TableBackgrounds( ww8::WW8TableNodeInfoInner::Pointer_t
m_rWW8Export.InsUInt16( aShd.GetValue() );
}
- sal_uInt32 const aSprmIds[] { NS_sprm::sprmTDefTableShd,
- NS_sprm::sprmTDefTableShdRaw };
+ sal_uInt32 const aSprmIds[] { NS_sprm::TDefTableShd::val,
+ NS_sprm::TDefTableShdRaw::val };
sal_uInt8 nBoxes0 = rTabBoxes.size();
if (nBoxes0 > 21)
nBoxes0 = 21;
diff --git a/sw/source/filter/ww8/wrtww8gr.cxx b/sw/source/filter/ww8/wrtww8gr.cxx
index 4f0de200ba6d..1795ee0ce9ea 100644
--- a/sw/source/filter/ww8/wrtww8gr.cxx
+++ b/sw/source/filter/ww8/wrtww8gr.cxx
@@ -336,16 +336,16 @@ void WW8Export::OutputLinkedOLE( const OUString& rOleId )
// Output the cPicLocation attribute
std::unique_ptr<ww::bytes> pBuf( new ww::bytes );
- SwWW8Writer::InsUInt16( *pBuf, NS_sprm::sprmCPicLocation );
+ SwWW8Writer::InsUInt16( *pBuf, NS_sprm::CPicLocation::val );
SwWW8Writer::InsUInt32( *pBuf, rOleId.copy( 1 ).toInt32() );
- SwWW8Writer::InsUInt16( *pBuf, NS_sprm::sprmCFOle2 );
+ SwWW8Writer::InsUInt16( *pBuf, NS_sprm::CFOle2::val );
pBuf->push_back( 1 );
- SwWW8Writer::InsUInt16( *pBuf, NS_sprm::sprmCFSpec );
+ SwWW8Writer::InsUInt16( *pBuf, NS_sprm::CFSpec::val );
pBuf->push_back( 1 );
- SwWW8Writer::InsUInt16( *pBuf, NS_sprm::sprmCFObj );
+ SwWW8Writer::InsUInt16( *pBuf, NS_sprm::CFObj::val );
pBuf->push_back( 1 );
m_pChpPlc->AppendFkpEntry( Strm().Tell(), pBuf->size(), pBuf->data() );
@@ -414,7 +414,7 @@ void WW8Export::OutGrf(const ww8::Frame &rFrame)
long nFontHeight = GetItem(RES_CHRATR_FONTSIZE).GetHeight();
nHeight-=nFontHeight/20;
- Set_UInt16( pArr, NS_sprm::sprmCHpsPos );
+ Set_UInt16( pArr, NS_sprm::CHpsPos::val );
Set_UInt16( pArr, - static_cast<sal_Int16>(nHeight));
}
}
@@ -425,7 +425,7 @@ void WW8Export::OutGrf(const ww8::Frame &rFrame)
Set_UInt8( pArr, 1 );
// sprmCPicLocation
- Set_UInt16( pArr, NS_sprm::sprmCPicLocation );
+ Set_UInt16( pArr, NS_sprm::CPicLocation::val );
Set_UInt32( pArr, GRF_MAGIC_321 );
// vary Magic, so that different graphic attributes will not be merged
diff --git a/sw/source/filter/ww8/ww8atr.cxx b/sw/source/filter/ww8/ww8atr.cxx
index 3a45a4cb5bb4..606e3356eb9f 100644
--- a/sw/source/filter/ww8/ww8atr.cxx
+++ b/sw/source/filter/ww8/ww8atr.cxx
@@ -749,11 +749,11 @@ void WW8AttributeOutput::OutlineNumbering(sal_uInt8 nLvl)
nLvl = WW8ListManager::nMaxLevel-1;
// write sprmPOutLvl sprmPIlvl and sprmPIlfo
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmPOutLvl );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::POutLvl::val );
m_rWW8Export.pO->push_back( nLvl );
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmPIlvl );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::PIlvl::val );
m_rWW8Export.pO->push_back( nLvl );
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmPIlfo );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::PIlfo::val );
SwWW8Writer::InsUInt16( *m_rWW8Export.pO,
1 + m_rWW8Export.GetNumberingId(*m_rWW8Export.m_pDoc->GetOutlineNumRule()) );
}
@@ -773,9 +773,9 @@ bool WW8Export::DisallowInheritingOutlineNumbering(const SwFormat &rFormat)
{
if (static_cast<const SwTextFormatColl*>(pParent)->IsAssignedToListLevelOfOutlineStyle())
{
- SwWW8Writer::InsUInt16(*pO, NS_sprm::sprmPOutLvl);
+ SwWW8Writer::InsUInt16(*pO, NS_sprm::POutLvl::val);
pO->push_back(sal_uInt8(9));
- SwWW8Writer::InsUInt16(*pO, NS_sprm::sprmPIlfo);
+ SwWW8Writer::InsUInt16(*pO, NS_sprm::PIlfo::val);
SwWW8Writer::InsUInt16(*pO, 0);
bRet = true;
@@ -980,7 +980,7 @@ void WW8AttributeOutput::RTLAndCJKState( bool bIsRTL, sal_uInt16 nScript )
{
if( m_rWW8Export.m_pDoc->GetDocumentType() != SwDoc::DOCTYPE_MSWORD )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFBiDi );
+ m_rWW8Export.InsUInt16( NS_sprm::CFBiDi::val );
m_rWW8Export.pO->push_back( sal_uInt8(1) );
}
}
@@ -988,7 +988,7 @@ void WW8AttributeOutput::RTLAndCJKState( bool bIsRTL, sal_uInt16 nScript )
// #i46087# patch from james_clark; complex texts needs the undocumented SPRM CComplexScript with param 0x81.
if (nScript == i18n::ScriptType::COMPLEX && !bIsRTL)
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFComplexScripts );
+ m_rWW8Export.InsUInt16( NS_sprm::CFComplexScripts::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x81) );
m_rWW8Export.pDop->bUseThaiLineBreakingRules = true;
}
@@ -1120,7 +1120,7 @@ void WW8AttributeOutput::ParagraphStyle( sal_uInt16 nStyle )
void WW8AttributeOutput::OutputWW8Attribute( sal_uInt8 nId, bool bVal )
{
- m_rWW8Export.InsUInt16( 8 == nId ? NS_sprm::sprmCFDStrike : NS_sprm::sprmCFBold + nId );
+ m_rWW8Export.InsUInt16( 8 == nId ? NS_sprm::CFDStrike::val : NS_sprm::CFBold::val + nId );
m_rWW8Export.pO->push_back( bVal ? 1 : 0 );
}
@@ -1131,7 +1131,7 @@ void WW8AttributeOutput::OutputWW8AttributeCTL( sal_uInt8 nId, bool bVal )
if (nId > 1)
return;
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFBoldBi + nId );
+ m_rWW8Export.InsUInt16( NS_sprm::CFBoldBi::val + nId );
m_rWW8Export.pO->push_back( bVal ? 1 : 0 );
}
@@ -1139,9 +1139,9 @@ void WW8AttributeOutput::CharFont( const SvxFontItem& rFont )
{
sal_uInt16 nFontID = m_rWW8Export.GetId( rFont );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCRgFtc0 );
+ m_rWW8Export.InsUInt16( NS_sprm::CRgFtc0::val );
m_rWW8Export.InsUInt16( nFontID );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCRgFtc2 );
+ m_rWW8Export.InsUInt16( NS_sprm::CRgFtc2::val );
m_rWW8Export.InsUInt16( nFontID );
}
@@ -1149,14 +1149,14 @@ void WW8AttributeOutput::CharFont( const SvxFontItem& rFont )
void WW8AttributeOutput::CharFontCTL( const SvxFontItem& rFont )
{
sal_uInt16 nFontID = m_rWW8Export.GetId( rFont );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFtcBi );
+ m_rWW8Export.InsUInt16( NS_sprm::CFtcBi::val );
m_rWW8Export.InsUInt16( nFontID );
}
void WW8AttributeOutput::CharFontCJK( const SvxFontItem& rFont )
{
sal_uInt16 nFontID = m_rWW8Export.GetId( rFont );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCRgFtc1 );
+ m_rWW8Export.InsUInt16( NS_sprm::CRgFtc1::val );
m_rWW8Export.InsUInt16( nFontID );
}
@@ -1193,21 +1193,21 @@ void WW8AttributeOutput::CharShadow( const SvxShadowedItem& rShadow )
void WW8AttributeOutput::CharKerning( const SvxKerningItem& rKerning )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCDxaSpace );
+ m_rWW8Export.InsUInt16( NS_sprm::CDxaSpace::val );
m_rWW8Export.InsUInt16( rKerning.GetValue() );
}
void WW8AttributeOutput::CharAutoKern( const SvxAutoKernItem& rAutoKern )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCHpsKern );
+ m_rWW8Export.InsUInt16( NS_sprm::CHpsKern::val );
m_rWW8Export.InsUInt16( rAutoKern.GetValue() ? 2 : 0 );
}
void WW8AttributeOutput::CharAnimatedText( const SvxBlinkItem& rBlink )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCSfxText );
+ m_rWW8Export.InsUInt16( NS_sprm::CSfxText::val );
// At the moment the only animated text effect we support is blinking
m_rWW8Export.pO->push_back( rBlink.GetValue() ? 2 : 0 );
}
@@ -1260,7 +1260,7 @@ void WW8AttributeOutput::CharHidden( const SvxCharHiddenItem& rHidden )
void WW8AttributeOutput::CharBorder( const SvxBorderLine* pAllBorder, const sal_uInt16 /*nDist*/, const bool bShadow )
{
- WW8Export::Out_BorderLine( *m_rWW8Export.pO, pAllBorder, 0, NS_sprm::sprmCBrc80, NS_sprm::sprmCBrc, bShadow );
+ WW8Export::Out_BorderLine( *m_rWW8Export.pO, pAllBorder, 0, NS_sprm::CBrc80::val, NS_sprm::CBrc::val, bShadow );
}
void WW8AttributeOutput::CharHighlight( const SvxBrushItem& rBrush )
@@ -1269,14 +1269,14 @@ void WW8AttributeOutput::CharHighlight( const SvxBrushItem& rBrush )
{
sal_uInt8 nColor = msfilter::util::TransColToIco( rBrush.GetColor() );
// sprmCHighlight
- m_rWW8Export.InsUInt16( NS_sprm::sprmCHighlight );
+ m_rWW8Export.InsUInt16( NS_sprm::CHighlight::val );
m_rWW8Export.pO->push_back( nColor );
}
}
void WW8AttributeOutput::CharUnderline( const SvxUnderlineItem& rUnderline )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCKul );
+ m_rWW8Export.InsUInt16( NS_sprm::CKul::val );
const SfxPoolItem* pItem = m_rWW8Export.HasItem( RES_CHRATR_WORDLINEMODE );
bool bWord = false;
@@ -1352,7 +1352,7 @@ void WW8AttributeOutput::CharUnderline( const SvxUnderlineItem& rUnderline )
Color aColor = rUnderline.GetColor();
if( aColor != COL_TRANSPARENT )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCCvUl );
+ m_rWW8Export.InsUInt16( NS_sprm::CCvUl::val );
m_rWW8Export.InsUInt32( wwUtility::RGBToBGR( aColor ) );
}
@@ -1364,13 +1364,13 @@ void WW8AttributeOutput::CharLanguage( const SvxLanguageItem& rLanguage )
switch ( rLanguage.Which() )
{
case RES_CHRATR_LANGUAGE:
- nId = NS_sprm::sprmCRgLid0_80;
+ nId = NS_sprm::CRgLid0_80::val;
break;
case RES_CHRATR_CJK_LANGUAGE:
- nId = NS_sprm::sprmCRgLid1_80;
+ nId = NS_sprm::CRgLid1_80::val;
break;
case RES_CHRATR_CTL_LANGUAGE:
- nId = NS_sprm::sprmCLidBi;
+ nId = NS_sprm::CLidBi::val;
break;
}
@@ -1382,14 +1382,14 @@ void WW8AttributeOutput::CharLanguage( const SvxLanguageItem& rLanguage )
// Word 2000 and above apparently require both old and new versions of
// these sprms to be set, without it spellchecking doesn't work
- if ( nId == NS_sprm::sprmCRgLid0_80 )
+ if ( nId == NS_sprm::CRgLid0_80::val )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCRgLid0 );
+ m_rWW8Export.InsUInt16( NS_sprm::CRgLid0::val );
m_rWW8Export.InsUInt16( static_cast<sal_uInt16>(rLanguage.GetLanguage()) );
}
- else if ( nId == NS_sprm::sprmCRgLid1_80 )
+ else if ( nId == NS_sprm::CRgLid1_80::val )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCRgLid1 );
+ m_rWW8Export.InsUInt16( NS_sprm::CRgLid1::val );
m_rWW8Export.InsUInt16( static_cast<sal_uInt16>(rLanguage.GetLanguage()) );
}
}
@@ -1429,7 +1429,7 @@ void WW8AttributeOutput::CharEscapement( const SvxEscapementItem& rEscapement )
if ( 0xFF != b )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCIss );
+ m_rWW8Export.InsUInt16( NS_sprm::CIss::val );
m_rWW8Export.pO->push_back( b );
}
@@ -1437,13 +1437,13 @@ void WW8AttributeOutput::CharEscapement( const SvxEscapementItem& rEscapement )
if ( 0 == b || 0xFF == b )
{
double fHeight = m_rWW8Export.GetItem( RES_CHRATR_FONTSIZE ).GetHeight();
- m_rWW8Export.InsUInt16( NS_sprm::sprmCHpsPos );
+ m_rWW8Export.InsUInt16( NS_sprm::CHpsPos::val );
m_rWW8Export.InsUInt16(static_cast<short>( round(fHeight * nEsc / 1000) ));
if( 100 != nProp || !b )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCHps );
+ m_rWW8Export.InsUInt16( NS_sprm::CHps::val );
m_rWW8Export.InsUInt16(msword_cast<sal_uInt16>( round(fHeight * nProp / 1000) ));
}
}
@@ -1456,10 +1456,10 @@ void WW8AttributeOutput::CharFontSize( const SvxFontHeightItem& rHeight )
{
case RES_CHRATR_FONTSIZE:
case RES_CHRATR_CJK_FONTSIZE:
- nId = NS_sprm::sprmCHps;
+ nId = NS_sprm::CHps::val;
break;
case RES_CHRATR_CTL_FONTSIZE:
- nId = NS_sprm::sprmCHpsBi;
+ nId = NS_sprm::CHpsBi::val;
break;
}
@@ -1473,7 +1473,7 @@ void WW8AttributeOutput::CharFontSize( const SvxFontHeightItem& rHeight )
void WW8AttributeOutput::CharScaleWidth( const SvxCharScaleWidthItem& rScaleWidth )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCCharScale );
+ m_rWW8Export.InsUInt16( NS_sprm::CCharScale::val );
m_rWW8Export.InsUInt16( rScaleWidth.GetValue() );
}
@@ -1482,8 +1482,8 @@ void WW8AttributeOutput::CharRelief( const SvxCharReliefItem& rRelief )
sal_uInt16 nId;
switch ( rRelief.GetValue() )
{
- case FontRelief::Embossed: nId = NS_sprm::sprmCFEmboss; break;
- case FontRelief::Engraved: nId = NS_sprm::sprmCFImprint; break;
+ case FontRelief::Embossed: nId = NS_sprm::CFEmboss::val; break;
+ case FontRelief::Engraved: nId = NS_sprm::CFImprint::val; break;
default: nId = 0; break;
}
@@ -1495,9 +1495,9 @@ void WW8AttributeOutput::CharRelief( const SvxCharReliefItem& rRelief )
else
{
// switch both flags off
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFEmboss );
+ m_rWW8Export.InsUInt16( NS_sprm::CFEmboss::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x0) );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFImprint );
+ m_rWW8Export.InsUInt16( NS_sprm::CFImprint::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x0) );
}
}
@@ -1527,11 +1527,11 @@ void WW8AttributeOutput::CharRotate( const SvxCharRotateItem& rRotate )
if (!m_rWW8Export.IsInTable())
{
// #i36867 In word the text in a table is rotated via the TC or NS_sprm::sprmTTextFlow
// This means you can only rotate all or none of the text adding NS_sprm::sprmCFELayout
// here corrupts the table, hence !m_rWW8Export.bIsInTable
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFELayout );
+ m_rWW8Export.InsUInt16( NS_sprm::CFELayout::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x06) ); //len 6
m_rWW8Export.pO->push_back( sal_uInt8(0x01) );
@@ -1557,7 +1557,7 @@ void WW8AttributeOutput::CharEmphasisMark( const SvxEmphasisMarkItem& rEmphasisM
// case 1:
nVal = 1;
- m_rWW8Export.InsUInt16( NS_sprm::sprmCKcd );
+ m_rWW8Export.InsUInt16( NS_sprm::CKcd::val );
m_rWW8Export.pO->push_back( nVal );
}
@@ -1591,14 +1591,14 @@ static sal_uInt32 SuitableBGColor(Color nIn)
void WW8AttributeOutput::CharColor( const SvxColorItem& rColor )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCIco );
+ m_rWW8Export.InsUInt16( NS_sprm::CIco::val );
sal_uInt8 nColor = msfilter::util::TransColToIco( rColor.GetValue() );
m_rWW8Export.pO->push_back( nColor );
if (nColor)
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCCv );
+ m_rWW8Export.InsUInt16( NS_sprm::CCv::val );
m_rWW8Export.InsUInt32( wwUtility::RGBToBGR( rColor.GetValue() ) );
}
}
@@ -1609,12 +1609,12 @@ void WW8AttributeOutput::CharBackground( const SvxBrushItem& rBrush )
WW8Export::TransBrush( rBrush.GetColor(), aSHD );
// sprmCShd80
- m_rWW8Export.InsUInt16( NS_sprm::sprmCShd80 );
+ m_rWW8Export.InsUInt16( NS_sprm::CShd80::val );
m_rWW8Export.InsUInt16( aSHD.GetValue() );
//Quite a few unknowns, some might be transparency or something
//of that nature...
- m_rWW8Export.InsUInt16( NS_sprm::sprmCShd );
+ m_rWW8Export.InsUInt16( NS_sprm::CShd::val );
m_rWW8Export.pO->push_back( 10 );
m_rWW8Export.InsUInt32( 0xFF000000 );
m_rWW8Export.InsUInt32( SuitableBGColor( rBrush.GetColor() ) );
@@ -1636,7 +1636,7 @@ void WW8AttributeOutput::TextINetFormat( const SwFormatINetFormat& rINet )
? m_rWW8Export.m_pDoc->FindCharFormatByName( rStr )
: m_rWW8Export.m_pDoc->getIDocumentStylePoolAccess().GetCharFormatFromPool( nId );
- m_rWW8Export.InsUInt16( NS_sprm::sprmCIstd );
+ m_rWW8Export.InsUInt16( NS_sprm::CIstd::val );
m_rWW8Export.InsUInt16( m_rWW8Export.GetId( pFormat ) );
}
@@ -1665,7 +1665,7 @@ static void InsertSpecialChar( WW8Export& rWrt, sal_uInt8 c,
if ( bIncludeEmptyPicLocation &&
( c == 0x13 || c == 0x14 || c == 0x15 ) )
{
- SwWW8Writer::InsUInt16( aItems, NS_sprm::sprmCPicLocation );
+ SwWW8Writer::InsUInt16( aItems, NS_sprm::CPicLocation::val );
SwWW8Writer::InsUInt32( aItems, 0x00000000 );
}
@@ -1704,11 +1704,11 @@ static void InsertSpecialChar( WW8Export& rWrt, sal_uInt8 c,
rStrm.Seek( nCurrPos );
// write attributes of hyperlink character 0x01
- SwWW8Writer::InsUInt16( aItems, NS_sprm::sprmCFFldVanish );
+ SwWW8Writer::InsUInt16( aItems, NS_sprm::CFFldVanish::val );
aItems.push_back( sal_uInt8(0x81) );
- SwWW8Writer::InsUInt16( aItems, NS_sprm::sprmCPicLocation );
+ SwWW8Writer::InsUInt16( aItems, NS_sprm::CPicLocation::val );
SwWW8Writer::InsUInt32( aItems, nLinkPosInDataStrm );
- SwWW8Writer::InsUInt16( aItems, NS_sprm::sprmCFData );
+ SwWW8Writer::InsUInt16( aItems, NS_sprm::CFData::val );
aItems.push_back( sal_uInt8(0x01) );
}
@@ -1717,7 +1717,7 @@ static void InsertSpecialChar( WW8Export& rWrt, sal_uInt8 c,
//is slightly lacking
//aItems.Remove(0, aItems.Count());
// fSpec-Attribute true
- SwWW8Writer::InsUInt16( aItems, NS_sprm::sprmCFSpec );
+ SwWW8Writer::InsUInt16( aItems, NS_sprm::CFSpec::val );
aItems.push_back( 1 );
rWrt.m_pChpPlc->AppendFkpEntry(rWrt.Strm().Tell(), aItems.size(), aItems.data());
@@ -1864,13 +1864,13 @@ void WW8Export::OutputField( const SwField* pField, ww::eField eFieldType,
sal_uInt8 aArr[12];
sal_uInt8 *pArr = aArr;
- Set_UInt16( pArr, NS_sprm::sprmCPicLocation );
+ Set_UInt16( pArr, NS_sprm::CPicLocation::val );
Set_UInt32( pArr, 0x0 );
- Set_UInt16( pArr, NS_sprm::sprmCFSpec );
+ Set_UInt16( pArr, NS_sprm::CFSpec::val );
Set_UInt8( pArr, 1 );
- Set_UInt16( pArr, NS_sprm::sprmCFNoProof );
+ Set_UInt16( pArr, NS_sprm::CFNoProof::val );
Set_UInt8( pArr, 1 );
m_pChpPlc->AppendFkpEntry( Strm().Tell(), static_cast< short >(pArr - aArr), aArr );
@@ -2602,7 +2602,7 @@ void WW8Export::WritePostItBegin( ww::bytes* pOut )
sal_uInt8* pArr = aArr;
// sprmCFSpec true
- Set_UInt16( pArr, NS_sprm::sprmCFSpec );
+ Set_UInt16( pArr, NS_sprm::CFSpec::val );
Set_UInt8( pArr, 1 );
m_pChpPlc->AppendFkpEntry( Strm().Tell() );
@@ -3293,26 +3293,26 @@ void AttributeOutputBase::TextFlyContent( const SwFormatFlyCnt& rFlyContent )
void WW8AttributeOutput::ParaHyphenZone( const SvxHyphenZoneItem& rHyphenZone )
{
// sprmPFNoAutoHyph
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFNoAutoHyph );
+ m_rWW8Export.InsUInt16( NS_sprm::PFNoAutoHyph::val );
m_rWW8Export.pO->push_back( rHyphenZone.IsHyphen() ? 0 : 1 );
}
void WW8AttributeOutput::ParaScriptSpace( const SfxBoolItem& rScriptSpace )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFAutoSpaceDE );
+ m_rWW8Export.InsUInt16( NS_sprm::PFAutoSpaceDE::val );
m_rWW8Export.pO->push_back( rScriptSpace.GetValue() ? 1 : 0 );
}
void WW8AttributeOutput::ParaHangingPunctuation( const SfxBoolItem& rItem )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFOverflowPunct );
+ m_rWW8Export.InsUInt16( NS_sprm::PFOverflowPunct::val );
m_rWW8Export.pO->push_back( rItem.GetValue() ? 1 : 0 );
}
void WW8AttributeOutput::ParaForbiddenRules( const SfxBoolItem& rItem )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFKinsoku );
+ m_rWW8Export.InsUInt16( NS_sprm::PFKinsoku::val );
m_rWW8Export.pO->push_back( rItem.GetValue() ? 1 : 0 );
}
@@ -3320,7 +3320,7 @@ void WW8AttributeOutput::ParaSnapToGrid( const SvxParaGridItem& rGrid )
{
// sprmPFUsePgsuSettings
- m_rWW8Export.InsUInt16( NS_sprm::sprmPFUsePgsuSettings );
+ m_rWW8Export.InsUInt16( NS_sprm::PFUsePgsuSettings::val );
m_rWW8Export.pO->push_back( rGrid.GetValue() ? 1 : 0 );
}
@@ -3328,7 +3328,7 @@ void WW8AttributeOutput::ParaVerticalAlign( const SvxParaVertAlignItem& rAlign )
{
// sprmPWAlignFont
- m_rWW8Export.InsUInt16( NS_sprm::sprmPWAlignFont );
+ m_rWW8Export.InsUInt16( NS_sprm::PWAlignFont::val );
SvxParaVertAlignItem::Align nAlign = rAlign.GetValue();
sal_uInt16 nVal;
@@ -3385,7 +3385,7 @@ void WW8Export::WriteFootnoteBegin( const SwFormatFootnote& rFootnote, ww::bytes
const SwCharFormat* pCFormat = pOutArr
? pInfo->GetAnchorCharFormat( *m_pDoc )
: pInfo->GetCharFormat( *m_pDoc );
- SwWW8Writer::InsUInt16( aAttrArr, NS_sprm::sprmCIstd );
+ SwWW8Writer::InsUInt16( aAttrArr, NS_sprm::CIstd::val );
SwWW8Writer::InsUInt16( aAttrArr, GetId( pCFormat ) );
// fSpec-Attribut true
@@ -3509,7 +3509,7 @@ void WW8AttributeOutput::TextCharFormat( const SwFormatCharFormat& rCharFormat )
{
if( rCharFormat.GetCharFormat() )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCIstd );
+ m_rWW8Export.InsUInt16( NS_sprm::CIstd::val );
m_rWW8Export.InsUInt16( m_rWW8Export.GetId( rCharFormat.GetCharFormat() ) );
}
@@ -3523,7 +3523,7 @@ void WW8AttributeOutput::CharTwoLines( const SvxTwoLinesItem& rTwoLines )
// #i28331# - check that bOn is set
if ( rTwoLines.GetValue() )
{
- m_rWW8Export.InsUInt16( NS_sprm::sprmCFELayout );
+ m_rWW8Export.InsUInt16( NS_sprm::CFELayout::val );
m_rWW8Export.pO->push_back( sal_uInt8(0x06) ); //len 6
m_rWW8Export.pO->push_back( sal_uInt8(0x02) );
@@ -3669,9 +3669,9 @@ void WW8AttributeOutput::ParaNumRule_Impl(const SwTextNode* /*pTextNd*/,
sal_Int32 const nLvl, sal_Int32 const nNumId)
{
// write sprmPIlvl and sprmPIlfo
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmPIlvl );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::PIlvl::val );
m_rWW8Export.pO->push_back( ::sal::static_int_cast<sal_uInt8>(nLvl) );
- SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::sprmPIlfo );
+ SwWW8Writer::InsUInt16( *m_rWW8Export.pO, NS_sprm::PIlfo::val );
SwWW8Writer::InsUInt16( *m_rWW8Export.pO, ::sal::static_int_cast<sal_uInt16>(nNumId) );
}
@@ -3688,14 +3688,14 @@ void WW8AttributeOutput::FormatFrameSize( const SwFormatFrameSize& rSize )
if ( rSize.GetWidth() && rSize.GetWidthSizeType() == SwFrameSize::Fixed)
{
//"sprmPDxaWidth"
- m_rWW8Export.InsUInt16( NS_sprm::sprmPDxaWidth );
+ m_rWW8Export.InsUInt16( NS_sprm::PDxaWidth::val );
m_rWW8Export.InsUInt16( static_cast<sal_uInt16>(rSize.GetWidth()) );
}
if ( rSize.GetHeight() )
{
// sprmPWHeightAbs
- m_rWW8Export.InsUInt16( NS_sprm::sprmPWHeightAbs );
+ m_rWW8Export.InsUInt16( NS_sprm::PWHeightAbs::val );
sal_uInt16 nH = 0;
switch ( rSize.GetHeightSizeType() )
@@ -3712,17 +3712,17 @@ void WW8AttributeOutput::FormatFrameSize( const SwFormatFrameSize& rSize )
if( m_rWW8Export.m_pCurrentPageDesc->GetLandscape() )
{
/*sprmSBOrientation*/
- m_rWW8Export.InsUInt16( NS_sprm::sprmSBOrientation );
+ m_rWW8Export.InsUInt16( NS_sprm::SBOrientation::val );
m_rWW8Export.pO->push_back( 2 );
}
/*sprmSXaPage*/
- m_rWW8Export.InsUInt16( NS_sprm::sprmSXaPage );
+ m_rWW8Export.InsUInt16( NS_sprm::SXaPage::val );
m_rWW8Export.InsUInt16(
msword_cast<sal_uInt16>(SvxPaperInfo::GetSloppyPaperDimension(rSize.GetWidth())));
/*sprmSYaPage*/
- m_rWW8Export.InsUInt16( NS_sprm::sprmSYaPage );
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
@@ -1527,11 +1527,11 @@ void WW8AttributeOutput::CharRotate( const SvxCharRotateItem& rRotate )
if (!m_rWW8Export.IsInTable())
{
- // #i36867 In word the text in a table is rotated via the TC or NS_sprm::sprmTTextFlow
- // This means you can only rotate all or none of the text adding NS_sprm::sprmCFELayout
+ // #i36867 In word the text in a table is rotated via the TC or NS_sprm::TTextFlow::val
+ // This means you can only rotate all or none of the text adding NS_sprm::CFELayout::val
// here corrupts the table, hence !m_rWW8Export.bIsInTable